Package: modreg
Version: 1.4.1
Priority: base
Title: Modern Regression: Smoothing and Local Methods
Author: Brian Ripley.
Maintainer: R Core Team <R-core@r-project.org>
Description: Modern regression: smoothing and local methods
License: GPL Version 2 or later.
