Package: mva
Version: 1.4.1
Priority: base
Title: Classical Multivariate Analysis
Author: R Development Core Team
Maintainer: R Core Team <R-core@r-project.org>
Description: Multivariate analysis
License: GPL Version 2 or later.
