Package: lqs
Version: 1.4.1
Priority: base
Title: Resistant Regression and Covariance Estimation
Author: Brian Ripley.
Maintainer: R Core Team <R-core@r-project.org>
Description: Resistant regression and covariance estimation
License: GPL Version 2 or later.
