Package: ts
Version: 1.4.1
Priority: base
Title: Time series functions
Author: Collected by Brian Ripley. See SOURCES.
Maintainer: R Core Team <R-core@r-project.org>
Description: Time series functions.
License: GPL Version 2 or later.
