Package: eda
Version: 1.4.1
Priority: base
Title: Exploratory Data Analysis
Author: R Development Core Team
Maintainer: R Core Team <R-core@r-project.org>
Description: Exploratory Data Analysis, in the Tukey sense
License: GPL Version 2 or later.
