###--- >>> `character' <<<----- Character Vectors

	## alias	 help(character)
	## alias	 help(as.character)
	## alias	 help(as.character.default)
	## alias	 help(as.character.factor)
	## alias	 help(is.character)

##___ Examples ___:

form <- y ~ a + b + c
as.character(form)  ## length 3
deparse(form)       ## like the input

## Keywords: 'character', 'classes'.


