###--- >>> `mtcars' <<<----- Motor Trend Road Tests

	## alias	 help(mtcars)

##___ Examples ___:

data(mtcars)
pairs(mtcars, main = "mtcars data")
coplot(mpg ~ disp | as.factor(cyl), data = mtcars,
       panel = panel.smooth, rows = 1)

## Keywords: 'datasets'.


