###--- >>> `R.Version' <<<----- Version Information

	## alias	 help(R.Version)
	## alias	 help(R.version)
	## alias	 help(version)
	## alias	 help(R.version.string)

##___ Examples ___:

R.version$os # to check how lucky you are ...
plot(0) # any plot
mtext(R.version.string, side=1,line=4,adj=1)# a useful bottom-right note

## Keywords: 'environment', 'sysdata', 'programming'.


