###--- >>> `system.time' <<<----- CPU Time Used

	## alias	 help(system.time)
	## alias	 help(unix.time)

##___ Examples ___:

system.time(for(i in 1:50) mad(runif(500)))
exT <- function(n = 100) {
  # Purpose: Test if system.time works ok;   n: loop size
  system.time(for(i in 1:n) x <- mean(rt(1000, df=4)))
}
#-- Try to interrupt one of the following (using Ctrl-C):
exT()                 #- `1.4' on -O-optimized Ultra1
system.time(exT())    #~ +/- same

## Keywords: 'utilities'.


