###--- >>> `profiler' <<<----- Constructor for Profiler Objects for Nonlinear Models

	## alias	 help(profiler)

##___ Examples ___:

# see documentation on individual methods

## Keywords: 'nonlinear', 'models'.


