###--- >>> `bindenv' <<<----- Binding and Environment Adjustments

	## alias	 help(bindenv)
	## alias	 help(lockEnvironment)
	## alias	 help(environmentIsLocked)
	## alias	 help(lockBinding)
	## alias	 help(makeActiveBinding)
	## alias	 help(bindingIsLocked)
	## alias	 help(bindingIsActive)

##___ Examples ___:

# locking environments
e<-new.env()
assign("x",1, env=e)
get("x",env=e)
lockEnvironment(e)
get("x",env=e)
assign("x",2, env=e)
try(assign("y",2, env=e)) # error

# locking bindings
e<-new.env()
assign("x",1, env=e)
get("x",env=e)
lockBinding("x", e)
try(assign("x",2, env=e)) # error

# active bindings
f<-local({
    x <- 1
    function(v) {
       if (missing(v))
           cat("get\n")
       else {
           cat("set\n")
           x <<- v
       }
       x
    }
})
makeActiveBinding("fred", f, .GlobalEnv)
bindingIsActive("fred", .GlobalEnv)
fred
fred<-2
fred

## Keywords: 'internal'.


