###--- >>> `NULL' <<<----- The Null Object

	## alias	 help(NULL)
	## alias	 help(as.null)
	## alias	 help(as.null.default)
	## alias	 help(is.null)

##___ Examples ___:

is.null(list())    # FALSE (on purpose!)
is.null(integer(0))# F
is.null(logical(0))# F
as.null(list(a=1,b='c'))

## Keywords: 'attribute', 'manip', 'list', 'sysdata'.


