###--- >>> `sunspots' <<<----- Monthly Sunspot Numbers, 1749-1983

	## alias	 help(sunspots)

##___ Examples ___:

data(sunspots)
plot(sunspots, main = "sunspots data", xlab = "Year",
     ylab = "Monthly sunspot numbers")

## Keywords: 'datasets'.


