###--- >>> `clearNames' <<<----- Remove the Names from an Object

	## alias	 help(clearNames)

##___ Examples ___:

data( women )
lapply( women, mean )               # has a names attribute
clearNames( lapply( women, mean ) ) # removes the names

## Keywords: 'list'.


