###--- >>> `Logistic' <<<----- The Logistic Distribution

	## alias	 help(dlogis)
	## alias	 help(plogis)
	## alias	 help(qlogis)
	## alias	 help(rlogis)

##___ Examples ___:

eps <- 100 * .Machine$double.eps
x <- c(0:4, rlogis(100))
all.equal(plogis(x),                 1 / (1 + exp(-x)), tol = eps)
all.equal(plogis(x, lower=FALSE),   exp(-x)/ (1 + exp(-x)), tol = eps)
all.equal(plogis(x, lower=FALSE, log=TRUE), -log(1 + exp(x)),  tol = eps)
all.equal(dlogis(x), exp(x) * (1 + exp(x))^-2, tol = eps)

var(rlogis(4000, 0, s = 5))# approximately (+/- 3)
pi^2/3 * 5^2

## Keywords: 'distribution'.


