###--- >>> `Cauchy' <<<----- The Cauchy Distribution

	## alias	 help(dcauchy)
	## alias	 help(pcauchy)
	## alias	 help(qcauchy)
	## alias	 help(rcauchy)

##___ Examples ___:

all.equal(dcauchy(-1:4), 1 / (pi*(1 + (-1:4)^2)))

## Keywords: 'distribution'.


