###--- >>> `comment' <<<----- Query or Set a `Comment' Attribute

	## alias	 help(comment)
	## alias	 help(comment<-)

##___ Examples ___:

x <- matrix(1:12, 3,4)
comment(x) <- c("This is my very important data from experiment #0234",
                "Jun 5, 1998")
x
comment(x)

## Keywords: 'attribute'.


