###--- >>> `HairEyeColor' <<<----- Hair and Eye Color of Statistics Students

	## alias	 help(HairEyeColor)

##___ Examples ___:

data(HairEyeColor)
## Full mosaic
mosaicplot(HairEyeColor)
## Aggregate over sex:
x <- apply(HairEyeColor, c(1, 2), sum)
x
mosaicplot(x, main = "Relation between hair and eye color")

## Keywords: 'datasets'.


