###--- >>> `files' <<<----- File Manipulation

	## alias	 help(files)
	## alias	 help(file.append)
	## alias	 help(file.copy)
	## alias	 help(file.create)
	## alias	 help(file.exists)
	## alias	 help(file.remove)
	## alias	 help(file.rename)
	## alias	 help(dir.create)
	## alias	 help(basename)
	## alias	 help(dirname)
	## alias	 help(path.expand)

##___ Examples ___:

cat("file A\n", file="A")
cat("file B\n", file="B")
file.append("A", "B")
file.create("A")
file.append("A", rep("B", 10))
if(interactive()) file.show("A")
file.copy("A", "C")
dir.create("tmp")
file.copy(c("A", "B"), "tmp")
unlink("tmp", recursive=TRUE)
file.remove("A", "B", "C")

basename(file.path("","p1","p2","p3","filename"))
dirname(file.path("","p1","p2","p3","filename"))

path.expand("~/foo")

## Keywords: 'file'.


