###--- >>> `diff' <<<----- Lagged Differences

	## alias	 help(diff)
	## alias	 help(diff.default)

##___ Examples ___:

diff(1:10, 2)
diff(1:10, 2, 2)
x <- cumsum(cumsum(1:10))
stopifnot(diff(x, lag = 2) == x[(1+2):10] - x[1:(10 - 2)],
          diff(x, lag = 2) == (3:10)^2,
          diff(diff(x))    == diff(x, differences = 2))

## Keywords: 'ts', 'arith'.


