###--- >>> `list' <<<----- Lists - Generic and Dotted Pairs

	## alias	 help(list)
	## alias	 help(pairlist)
	## alias	 help(alist)
	## alias	 help(as.list)
	## alias	 help(as.list.default)
	## alias	 help(as.list.data.frame)
	## alias	 help(as.pairlist)
	## alias	 help(is.list)
	## alias	 help(is.pairlist)

##___ Examples ___:

data(cars)
# create a plotting structure
pts <- list(x=cars[,1], y=cars[,2])
plot(pts)

# Argument lists
f <- function()x
# Note the specification of a "..." argument:
formals(f) <- al <- alist(x=, y=2, ...=)
f
str(al)

str(pl <- as.pairlist(ps.options()))

## These are all TRUE:
is.list(pl) && is.pairlist(pl)
!is.null(list())
is.null(pairlist())
!is.list(NULL)
is.pairlist(pairlist())
is.null(as.pairlist(list()))
is.null(as.pairlist(NULL))

## Keywords: 'list', 'manip'.


