###--- >>> `options' <<<----- Options Settings

	## alias	 help(options)
	## alias	 help(.Options)
	## alias	 help(getOption)

##___ Examples ___:

options() # printing all current options
op <- options(); str(op) # nicer printing

# .Options is the same:
all(sapply(1:length(op), function(i) all(.Options[[i]] == op[[i]])))

options('width')[[1]] == options()$width # the latter needs more memory
options(digits=20)
pi

# set the editor, and save previous value
old.o <- options(editor="nedit")
old.o

options(check.bounds = TRUE)
x <- NULL; x[4] <- "yes" # gives a warning

options(op)     # reset (all) initial options
options('digits')

##Don't run: ## set contrast handling to be like S
##D options(contrasts=c("contr.helmert", "contr.poly"))

##Don't run: ## on error, terminate the R session with error status 66
##D options(error=quote(q("no", status=66, runLast=FALSE)))
##D stop("test it")

##Don't run: ## set an error action for debugging: see ?debugger.
##D options(error=quote(dump.frames()))
##D ## A possible setting for non-interactive sessions
##D options(error=quote({dump.frames(to.file=TRUE); q()}))

## Keywords: 'environment', 'error', 'print'.


