###--- >>> `predict.loess' <<<----- Predict Loess Curve or Surface

	## alias	 help(predict.loess)

##___ Examples ___:

data(cars)
cars.lo <- loess(dist ~ speed, cars)
predict(cars.lo, data.frame(speed=seq(5, 30, 1)), se=TRUE)
# to get extrapolation
cars.lo2 <- loess(dist ~ speed, cars,
  control=loess.control(surface="direct"))
predict(cars.lo2, data.frame(speed=seq(5, 30, 1)), se=TRUE)

## Keywords: 'smooth'.


