###--- >>> `row/colnames' <<<----- Row and Columnn Names

	## alias	 help(rownames)
	## alias	 help(rownames<-)
	## alias	 help(colnames)
	## alias	 help(colnames<-)

##___ Examples ___:

m0 <- matrix(NA, 4, 0)
m2 <- cbind(1,1:4)
rownames(m0)

        rownames(m0, do.NULL = FALSE)
        colnames(m0, do.NULL = FALSE)

colnames(m2, do.NULL = FALSE)
colnames(m2) <- c("x","Y")
rownames(m2) <- rownames(m2, do.NULL = FALSE, prefix = "Obs.")
m2

## Keywords: 'array', 'manip'.


