###--- >>> `Rprof' <<<----- Enable Profiling of R's Execution

	## alias	 help(Rprof)

##___ Examples ___:

##Don't run: Rprof()
##D ## some code to be profiled
##D Rprof(NULL)
##D ## some code NOT to be profiled
##D Rprof(append=TRUE)
##D ## some code to be profiled
##D Rprof(NULL)
##D ...
##D ## Post-process the output by
##D ##   R CMD Rprof Rprof.out
##D ## at the shell prompt.


## Keywords: 'utilities'.


