###--- >>> `which.min' <<<----- Where is the Min() or Max() ?

	## alias	 help(which.min)
	## alias	 help(which.max)

##___ Examples ___:

x <- c(1:4,0:5,11)
which.min(x)
which.max(x)

data(presidents)
presidents[1:30]
range(presidents, na.rm = TRUE)
which.min(presidents)# 28
which.max(presidents)# 2

  stopifnot(length(which.min(numeric(0))) == 0)
  stopifnot(length(which.max( c(NA,NA) )) == 0)


## Keywords: 'utilities'.


