###--- >>> `step' <<<----- Choose a model by AIC in a Stepwise Algorithm

	## alias	 help(step)

##___ Examples ___:

example(lm)
step(lm.D9)  

data(swiss)
summary(lm1 <- lm(Fertility ~ ., data = swiss))
slm1 <- step(lm1)
summary(slm1)
slm1$anova

## Keywords: 'models'.


