###--- >>> `array' <<<----- Multi-way Arrays

	## alias	 help(array)
	## alias	 help(as.array)
	## alias	 help(is.array)

##___ Examples ___:

dim(as.array(letters))
array(1:3, c(2,4)) # recycle 1:3 "2 2/3 times"
#     [,1] [,2] [,3] [,4]
#[1,]    1    3    2    1
#[2,]    2    1    3    2

## Keywords: 'array'.


