###--- >>> `rug' <<<----- Add a Rug to a Plot

	## alias	 help(rug)

##___ Examples ___:

data(faithful)
attach(faithful)
plot(density(eruptions, bw=0.15))
rug(eruptions)
rug(jitter(eruptions, amount = .01), side = 3, col = "light blue")
detach("faithful")

## Keywords: 'hplot'.


