###--- >>> `dev2' <<<----- Copy Graphics Between Multiple Devices

	## alias	 help(dev.copy)
	## alias	 help(dev.print)
	## alias	 help(dev.copy2eps)
	## alias	 help(dev.control)

##___ Examples ___:

##Don't run: 
##D x11()
##D plot(rnorm(10), main="Plot 1")
##D dev.copy(device=x11)
##D mtext("Copy 1", 3)
##D dev.print(width=6, height=6, horizontal=FALSE) # prints it
##D dev.off(dev.prev())
##D dev.off()


## Keywords: 'device'.


