###--- >>> `Uniform' <<<----- The Uniform Distribution

	## alias	 help(dunif)
	## alias	 help(punif)
	## alias	 help(qunif)
	## alias	 help(runif)

##___ Examples ___:

u <- runif(20)

## The following relations always hold :
 punif(u) == u
 dunif(u) == 1
 runif(10, 2,2) == 2

 stopifnot(punif(u) == u, dunif(u) == 1,
           runif(100, 2,2) == 2)#-> TRUE [bug in R version <= 0.63.1]

var(runif(10000))#- ~ = 1/12 = .08333

## Keywords: 'distribution'.


