###--- >>> `formula' <<<----- Model Formulae

	## alias	 help(~)
	## alias	 help(I)
	## alias	 help(formula)
	## alias	 help(formula.default)
	## alias	 help(formula.formula)
	## alias	 help(formula.terms)
	## alias	 help(formula.data.frame)
	## alias	 help(as.formula)
	## alias	 help(print.formula)

##___ Examples ___:

class(fo <- y ~ x1*x2) # "formula"
fo
typeof(fo)# R internal : "language"
terms(fo)

environment(fo)
environment(as.formula("y~x"))
environment(as.formula("y~x",env=new.env()))

## Create a formula for a model with a large number of variables:
xnam <- paste("x", 1:25, sep="")
(fmla <- as.formula(paste("y ~ ", paste(xnam, collapse= "+"))))

## Keywords: 'models'.


