###--- >>> `islands' <<<----- Areas of the World's Major Landmasses

	## alias	 help(islands)

##___ Examples ___:

data(islands)
dotchart(log(islands, 10),
   main = "islands data: log10(area) (log10(sq. miles))")
dotchart(log(islands[order(islands)], 10),
   main = "islands data: log10(area) (log10(sq. miles))")

## Keywords: 'datasets'.


