###--- >>> `bartlett.test' <<<----- Bartlett Test for Homogeneity of Variances

	## alias	 help(bartlett.test)
	## alias	 help(bartlett.test.default)
	## alias	 help(bartlett.test.formula)

##___ Examples ___:

data(InsectSprays)
plot(count ~ spray, data = InsectSprays)
bartlett.test(InsectSprays$count, InsectSprays$spray)
bartlett.test(count ~ spray, data = InsectSprays)

## Keywords: 'htest'.


