###--- >>> `Sys.getenv' <<<----- Get Environment Variables

	## alias	 help(Sys.getenv)

##___ Examples ___:

Sys.getenv(c("R_HOME", "R_PAPERSIZE", "R_PRINTCMD", "HOST"))

## Keywords: 'environment', 'utilities'.


