###--- >>> `locales' <<<----- Query or Set Aspects of the Locale

	## alias	 help(locales)
	## alias	 help(Sys.getlocale)
	## alias	 help(Sys.setlocale)

##___ Examples ___:

Sys.getlocale()
Sys.getlocale("LC_TIME")
##Don't run: 
##D Sys.setlocale("LC_TIME", "de")     # Solaris: details are OS-dependent
##D Sys.setlocale("LC_TIME", "German") # Windows

Sys.setlocale("LC_COLLATE", "C")  # turn off locale-specific sorting

## Keywords: 'utilities'.


