###--- >>> `box' <<<----- Draw a Box around a Plot

	## alias	 help(box)

##___ Examples ___:

plot(1:7,abs(rnorm(7)), type='h', axes = FALSE)
axis(1, labels = letters[1:7])
box(lty='137', col = 'red')

## Keywords: 'aplot'.


