###--- >>> `lm.influence' <<<----- Regression Diagnostics

	## alias	 help(lm.influence)

##___ Examples ___:

## Analysis of the life-cycle savings data
## given in Belsley, Kuh and Welsch.
data(LifeCycleSavings)
summary(lm.SR <- lm(sr ~ pop15 + pop75 + dpi + ddpi,
                    data = LifeCycleSavings),
        corr = TRUE)
str(lmI <- lm.influence(lm.SR))

## For more `user level' examples, use example(influence.measures)

## Keywords: 'regression'.


