###--- >>> `plot.histogram' <<<----- Plot Histograms

	## alias	 help(plot.histogram)
	## alias	 help(lines.histogram)

##___ Examples ___:

data(women)
str(wwt <- hist(women$weight, nc= 7, plot = FALSE))
plot(wwt, labels = TRUE) # default main & xlab using wwt$xname
plot(wwt, border = "dark blue", col = "light blue",
     main = "Histogram of 15 women's weights", xlab = "weight [pounds]")

## Fake "lines" example, using non-default labels:
w2 <- wwt; w2$counts <- w2$counts - 1
lines(w2, col = "Midnight Blue", labels = ifelse(w2$counts, "> 1", "1"))

## Keywords: 'hplot', 'iplot'.


