###--- >>> `fix' <<<----- Fix an Object

	## alias	 help(fix)

##___ Examples ___:

##Don't run: 
##D  ## Assume  `my.fun' is a user defined function :
##D  fix(my.fun)
##D  ## now my.fun is changed
##D  ## Also,
##D  fix(my.data.frame) # calls up data editor
##D  fix(my.data.frame, factor.mode="char") # use of ...


 if(machine() != "Macintosh") {
  oo <- options(editor="touch") # not really changing anything
  fix(pi)
  if(!is.numeric(pi) || length(pi)!=1 ||
     !is.null(attributes(pi)) || abs(pi - 3.1415) > 1e-4)
        stop("OOPS:  fix() is broken ...")
  rm(pi); options(oo)
 }


## Keywords: 'utilities'.


