###--- >>> `Memory' <<<----- Memory Available for Data Storage

	## alias	 help(Memory)
	## alias	 help(mem.limits)

##___ Examples ___:

# Start R with 10MB of heap memory and 500k cons cells, limit to
# 100Mb and 1M cells
##Don't run: 
##D ## Unix
##D R --min-vsize=10M --max-vsize=100M --min-nsize=500k --max-nsize=1M


## Keywords: 'environment'.


