###--- >>> `medpolish' <<<----- Median Polish of a Matrix

	## alias	 help(medpolish)
	## alias	 help(plot.medpolish)
	## alias	 help(print.medpolish)

##___ Examples ___:

## Deaths from sport parachuting;  from ABC of EDA, p.224:
deaths <-
    rbind(c(14,15,14),
          c( 7, 4, 7),
          c( 8, 2,10),
          c(15, 9,10),
          c( 0, 2, 0))
dimnames(deaths) <- list(c("1-24", "25-74", "75-199", "200++", "NA"),
                         paste(1973:1975))
deaths
(med.d <- medpolish(deaths))
plot(med.d)
## Check decomposition:
all(deaths == med.d$overall + outer(med.d$row,med.d$col, "+") + med.d$resid)

## Keywords: 'robust'.


