###--- >>> `NLSstClosestX' <<<----- Inverse Interpolation

	## alias	 help(NLSstClosestX)
	## alias	 help(NLSstClosestX.sortedXyData)

##___ Examples ___:

data( DNase )
DNase.2 <- DNase[ DNase$Run == "2", ]
DN.srt <- sortedXyData( expression(log(conc)), expression(density), DNase.2 )
NLSstClosestX( DN.srt, 1.0 )

## Keywords: 'manip'.


