###--- >>> `col' <<<----- Column Indexes

	## alias	 help(col)

##___ Examples ___:

# extract an off-diagonal of a matrix
ma <- matrix(1:12, 3, 4)
ma[row(ma) == col(ma) + 1]

# create an identity 5-by-5 matrix
x <- matrix(0, nr = 5, nc = 5)
x[row(x) == col(x)] <- 1

## Keywords: 'array'.


