###--- >>> `loess' <<<----- Local Polynomial Regression Fitting

	## alias	 help(loess)
	## alias	 help(anova.loess)
	## alias	 help(print.loess)
	## alias	 help(summary.loess)
	## alias	 help(print.summary.loess)

##___ Examples ___:

data(cars)
cars.lo <- loess(dist ~ speed, cars)
predict(cars.lo, data.frame(speed = seq(5, 30, 1)), se = TRUE)
# to allow extrapolation
cars.lo2 <- loess(dist ~ speed, cars,
  control = loess.control(surface = "direct"))
predict(cars.lo2, data.frame(speed = seq(5, 30, 1)), se = TRUE)

## Keywords: 'smooth', 'loess'.


