###--- >>> `iris' <<<----- Edgar Anderson's Iris Data

	## alias	 help(iris)
	## alias	 help(iris3)

##___ Examples ___:

data(iris3)
dni3 <- dimnames(iris3)
ii <- data.frame(matrix(aperm(iris3, c(1,3,2)), ncol=4,
                   dimnames=list(NULL, sub(" L.",".Length",
                                           sub(" W.",".Width", dni3[[2]])))),
                 Species = gl(3,50,lab=sub("S","s",sub("V","v",dni3[[3]]))))
data(iris)
all.equal(ii, iris) # TRUE

## Keywords: 'datasets'.


