###--- >>> `png' <<<----- JPEG and PNG graphics devices

	## alias	 help(png)
	## alias	 help(jpeg)

##___ Examples ___:

## these examples will work only if the devices are available
## and the X11 display is available.

## copy current plot to a PNG file
##Don't run: dev.print(png, file="myplot.png", width=480, height=480)
##D 
##D png(file="myplot.png", bg="transparent")
##D plot(1:10)
##D rect(1, 5, 3, 7, col="white")
##D dev.off()
##D 
##D jpeg(file="myplot.jpeg")
##D example(rect)
##D dev.off()

## Keywords: 'device'.


