###--- >>> `dput' <<<----- Write an Internal Object to a File

	## alias	 help(dput)
	## alias	 help(dget)

##___ Examples ___:

## Write an ASCII version of mean to the file "foo"
dput(mean, "foo")
## And read it back into `bar'
bar <- dget("foo")
unlink("foo")

## Keywords: 'file', 'programming', 'connection'.


