###--- >>> `ftable.formula' <<<----- Formula Notation for Flat Contingency Tables

	## alias	 help(ftable.formula)

##___ Examples ___:

data(Titanic)
Titanic
x <- ftable(Survived ~ ., data = Titanic)
x
ftable(Sex ~ Class + Age, data = x)

## Keywords: 'category'.


