###--- >>> `object.size' <<<----- Report the Space Allocated for an Object

	## alias	 help(object.size)

##___ Examples ___:

object.size(letters)
object.size(ls)
## find the 10 largest objects in base
z <- sapply(ls("package:base"), function(x) object.size(get(x)))
as.matrix(rev(sort(z))[1:10])

## Keywords: 'utilities'.


