###--- >>> `selfStart.default' <<<----- Construct Self-starting Nonlinear Models

	## alias	 help(selfStart.default)

##___ Examples ___:

# `first.order.log.model' is a function object defining a first order
# compartment model 
# `first.order.log.initial' is a function object which calculates initial
# values for the parameters in `first.order.log.model'

# self-starting first order compartment model
##Don't run: 
##D SSfol <- selfStart(first.order.log.model, first.order.log.initial)


## Keywords: 'models'.


