###--- >>> `extractAIC' <<<----- Extract AIC from a Fitted Model

	## alias	 help(extractAIC)
	## alias	 help(extractAIC.aov)
	## alias	 help(extractAIC.lm)
	## alias	 help(extractAIC.glm)
	## alias	 help(extractAIC.coxph)
	## alias	 help(extractAIC.negbin)
	## alias	 help(extractAIC.survreg)

##___ Examples ___:

example(glm)
extractAIC(glm.D93)#>>  5  15.129

## Keywords: 'models'.


