###--- >>> `match.call' <<<----- Argument Matching

	## alias	 help(match.call)

##___ Examples ___:

match.call(get, call("get", "abc", i = FALSE, p = 3))
## -> get(x = "abc", pos = 3, inherits = FALSE)
fun <- function(x, lower = 0, upper = 1) {
  structure((x - lower) / (upper - lower), CALL = match.call())
}
fun(4 * atan(1), u = pi)

## Keywords: 'programming'.


