###--- >>> `USJudgeRatings' <<<----- Lawyers' Ratings of State Judges in the US Superior Court

	## alias	 help(USJudgeRatings)

##___ Examples ___:

data(USJudgeRatings)
pairs(USJudgeRatings, main = "USJudgeRatings data")

## Keywords: 'datasets'.


