###--- >>> `match.fun' <<<----- Function Verification for ``Function Variables''

	## alias	 help(match.fun)

##___ Examples ___:

# Same as get("*"):
match.fun("*")
# Overwrite outer with a vector
outer <- 1:5
##Don't run: 
##D match.fun(outer, descend = FALSE) #-> Error:  not a function

match.fun(outer) # finds it anyway
is.function(match.fun("outer")) # as well

## Keywords: 'programming'.


