###--- >>> `prompt' <<<----- Produce Prototype of an R Documentation File

	## alias	 help(prompt)
	## alias	 help(prompt.default)
	## alias	 help(prompt.data.frame)

##___ Examples ___:

prompt(plot.default)
prompt(interactive, force.function = TRUE)
unlink("plot.default.Rd")
unlink("interactive.Rd")

data(women) # data.frame
prompt(women)
unlink("women.Rd")

data(sunspots) # non-data.frame data
prompt(sunspots)
unlink("sunspots.Rd")

## Keywords: 'documentation'.


