###--- >>> `vector' <<<----- Vectors

	## alias	 help(vector)
	## alias	 help(as.vector)
	## alias	 help(as.vector.factor)
	## alias	 help(is.vector)

##___ Examples ___:

df <- data.frame(x=1:3, y=5:7)
##Don't run: ## Error:
##D   as.vector(data.frame(x=1:3, y=5:7), mode="numeric")


x <- c(a = 1, b = 2)
is.vector(x)
as.vector(x)
all.equal(x, as.vector(x)) ## FALSE

###-- All the following are TRUE:
is.list(df)
! is.vector(df)
! is.vector(df, mode="list")

is.vector(list(), mode="list")
is.vector(NULL,   mode="NULL")

## Keywords: 'classes'.


