###--- >>> `names' <<<----- The Names Attribute of an Object

	## alias	 help(names)
	## alias	 help(names.default)
	## alias	 help(names<-)
	## alias	 help(names<-.default)

##___ Examples ___:

data(islands)
# print the names attribute of the islands data set
names(islands)

# remove the names attribute
names(islands) <- NULL

z <- list(a=1, b="c", c=1:3)
names(z)
# change just the name of the third element.
names(z)[3] <- "c2"
z

## Keywords: 'attribute'.


