###--- >>> `demo' <<<----- Demonstrations of R functionality

	## alias	 help(demo)

##___ Examples ___:

demo() # for attached packages

## All available demos:
demo(package = .packages(all.available = TRUE))

demo(lm.glm)

demo(nlm)

##Don't run: 
##D  ch <- "scoping"
##D  demo(ch, character = TRUE)


## Keywords: 'documentation', 'utilities'.


