###--- >>> `pairwise.t.test' <<<----- Pairwise t tests

	## alias	 help(pairwise.t.test)

##___ Examples ___:

data(airquality)
attach(airquality)
Month <- factor(Month, labels = month.abb[5:9])
pairwise.t.test(Ozone, Month)
pairwise.t.test(Ozone, Month, p.adj = "bonf")
pairwise.t.test(Ozone, Month, pool.sd = FALSE)
detach()

## Keywords: 'htest'.


