###--- >>> `prcomp' <<<----- Principal Components Analysis

	## alias	 help(prcomp)
	## alias	 help(plot.prcomp)
	## alias	 help(print.prcomp)
	## alias	 help(summary.prcomp)
	## alias	 help(print.summary.prcomp)

##___ Examples ___:

## the variances of the variables in the
## USArrests data vary by orders of magnitude, so scaling is appropriate
data(USArrests)
prcomp(USArrests)  # inappropriate
prcomp(USArrests, scale = TRUE)
plot(prcomp(USArrests))
summary(prcomp(USArrests, scale = TRUE))

## Keywords: 'multivariate'.


