###--- >>> `precip' <<<----- Annual Precipitation in US Cities

	## alias	 help(precip)

##___ Examples ___:

data(precip)
dotchart(precip[order(precip)], main = "precip data")
title(sub = "Average annual precipitation (in.)")

## Keywords: 'datasets'.


