###--- >>> `chol' <<<----- The Choleski Decomposition

	## alias	 help(chol)

##___ Examples ___:

( m <- matrix(c(5,1,1,3),2,2) )
( cm <- chol(m) )
t(cm) %*% cm  #-- = 'm'
all(abs(m  -  t(cm) %*% cm) < 100* .Machine$double.eps) # TRUE

## Keywords: 'algebra', 'array'.


