###--- >>> `conflicts' <<<----- Search for Masked Objects on the Search Path

	## alias	 help(conflicts)

##___ Examples ___:

lm <- 1:3
conflicts(, TRUE)
## gives something like
# $.GlobalEnv
# [1] "lm"
#
# $package:base
# [1] "lm"

## Remove things from your "workspace" that mask others:
remove(list = conflicts(detail=TRUE)$.GlobalEnv)

## Keywords: 'utilities'.


