###--- >>> `Weibull' <<<----- The Weibull Distribution

	## alias	 help(dweibull)
	## alias	 help(pweibull)
	## alias	 help(qweibull)
	## alias	 help(rweibull)

##___ Examples ___:

x <- c(0,rlnorm(50))
all.equal(dweibull(x, shape = 1), dexp(x))
all.equal(pweibull(x, shape = 1, scale = pi), pexp(x, rate = 1/pi))
## Cumulative hazard H():
all.equal(pweibull(x, 2.5, pi, lower=FALSE, log=TRUE), -(x/pi)^2.5, tol=1e-15)
all.equal(qweibull(x/11, shape = 1, scale = pi), qexp(x/11, rate = 1/pi))

## Keywords: 'distribution'.


