###--- >>> `all' <<<----- Are All Values True?

	## alias	 help(all)

##___ Examples ___:

range(x <- sort(round(rnorm(10) - 1.2,1)))
if(all(x < 0)) cat("all x values are negative\n")

## Keywords: 'logic'.


