###--- >>> `NotYet' <<<----- Not Yet Implemented Functions and Unused Arguments

	## alias	 help(NotYetImplemented)
	## alias	 help(.NotYetImplemented)
	## alias	 help(NotYetUsed)
	## alias	 help(.NotYetUsed)

##___ Examples ___:

plot.mlm         # to see how the ``NotYetImplemented''
                 # reference is made automagically
try(plot.mlm())

barplot(1:5, inside = TRUE) # `inside' is not yet used

## Keywords: 'documentation', 'utilities'.


