###--- >>> `Sys.putenv' <<<----- Set Environment Variables

	## alias	 help(Sys.putenv)

##___ Examples ___:

print(Sys.putenv("R_TEST"="testit", ABC=123))
Sys.getenv("R_TEST")

## Keywords: 'environment', 'utilities'.


