###--- >>> `periodicSpline' <<<----- Create a Periodic Interpolation Spline

	## alias	 help(periodicSpline)
	## alias	 help(periodicSpline.default)
	## alias	 help(periodicSpline.formula)

##___ Examples ___:

xx <- seq( -pi, pi, len = 16 )[-1]
yy <- sin( xx )
frm <- data.frame( xx, yy )
( pispl <- periodicSpline( xx, yy, period = 2 * pi ) )
pispl2 <- periodicSpline( yy ~ xx, frm, period = 2 * pi )
stopifnot(all.equal(pispl, pispl2))# pispl and pispl2 are the same

plot( pispl )          # displays over one period
points( yy ~ xx, col = "brown")
plot( predict( pispl, seq(-3*pi, 3*pi, len = 101) ), type = "l" )

## Keywords: 'models'.


