###--- >>> `chol2inv' <<<----- Inverse from Choleski Decomposition

	## alias	 help(chol2inv)

##___ Examples ___:

cma <- chol(ma  <- cbind(1, 1:3, c(1,3,7)))
t(cma) %*% cma # = ma
all.equal(diag(3), ma %*% chol2inv(cma))

## Keywords: 'algebra', 'array'.


