###--- >>> `max.col' <<<----- Find Maximum Position in Matrix

	## alias	 help(max.col)

##___ Examples ___:

data(swiss)
table(mc <- max.col(swiss))# mostly "1" and "5", 5 x "2" and once "4"
swiss[unique(print(mr <- max.col(t(swiss)))) , ] # 3 33 45 45 33 6

## Keywords: 'utilities', 'array'.


