###--- >>> `TkCommands' <<<----- Tk non-widget commands

	## alias	 help(TkCommands)
	## alias	 help(tkcmd)
	## alias	 help(tktitle)
	## alias	 help(tktitle<-)
	## alias	 help(tkbell)
	## alias	 help(tkbind)
	## alias	 help(tkbindtags)
	## alias	 help(tkfocus)
	## alias	 help(tklower)
	## alias	 help(tkraise)
	## alias	 help(tkclipboard.append)
	## alias	 help(tkclipboard.clear)
	## alias	 help(tkevent.add)
	## alias	 help(tkevent.delete)
	## alias	 help(tkevent.generate)
	## alias	 help(tkevent.info)
	## alias	 help(tkfont.actual)
	## alias	 help(tkfont.configure)
	## alias	 help(tkfont.create)
	## alias	 help(tkfont.delete)
	## alias	 help(tkfont.families)
	## alias	 help(tkfont.measure)
	## alias	 help(tkfont.metrics)
	## alias	 help(tkfont.names)
	## alias	 help(tkgrab)
	## alias	 help(tkgrab.current)
	## alias	 help(tkgrab.release)
	## alias	 help(tkgrab.set)
	## alias	 help(tkgrab.status)
	## alias	 help(tkXselection.clear)
	## alias	 help(tkXselection.get)
	## alias	 help(tkXselection.handle)
	## alias	 help(tkXselection.own)
	## alias	 help(tkwait.variable)
	## alias	 help(tkwait.visibility)
	## alias	 help(tkwait.window)
	## alias	 help(tkwinfo)
	## alias	 help(tkwm.aspect)
	## alias	 help(tkwm.client)
	## alias	 help(tkwm.colormapwindows)
	## alias	 help(tkwm.command)
	## alias	 help(tkwm.deiconify)
	## alias	 help(tkwm.focusmodel)
	## alias	 help(tkwm.frame)
	## alias	 help(tkwm.geometry)
	## alias	 help(tkwm.grid)
	## alias	 help(tkwm.group)
	## alias	 help(tkwm.iconbitmap)
	## alias	 help(tkwm.iconify)
	## alias	 help(tkwm.iconmask)
	## alias	 help(tkwm.iconname)
	## alias	 help(tkwm.iconposition)
	## alias	 help(tkwm.iconwindow)
	## alias	 help(tkwm.maxsize)
	## alias	 help(tkwm.minsize)
	## alias	 help(tkwm.overrideredirect)
	## alias	 help(tkwm.positionfrom)
	## alias	 help(tkwm.protocol)
	## alias	 help(tkwm.resizable)
	## alias	 help(tkwm.sizefrom)
	## alias	 help(tkwm.state)
	## alias	 help(tkwm.title)
	## alias	 help(tkwm.transient)
	## alias	 help(tkwm.withdraw)
	## alias	 help(tkgrid)
	## alias	 help(tkgrid.bbox)
	## alias	 help(tkgrid.columnconfigure)
	## alias	 help(tkgrid.configure)
	## alias	 help(tkgrid.forget)
	## alias	 help(tkgrid.info)
	## alias	 help(tkgrid.location)
	## alias	 help(tkgrid.propagate)
	## alias	 help(tkgrid.rowconfigure)
	## alias	 help(tkgrid.remove)
	## alias	 help(tkgrid.size)
	## alias	 help(tkgrid.slaves)
	## alias	 help(tkpack)
	## alias	 help(tkpack.configure)
	## alias	 help(tkpack.forget)
	## alias	 help(tkpack.info)
	## alias	 help(tkpack.propagate)
	## alias	 help(tkpack.slaves)
	## alias	 help(tkplace)
	## alias	 help(tkplace.configure)
	## alias	 help(tkplace.forget)
	## alias	 help(tkplace.info)
	## alias	 help(tkplace.slaves)
	## alias	 help(tkgetOpenFile)
	## alias	 help(tkgetSaveFile)
	## alias	 help(tkmessageBox)
	## alias	 help(tkfile.tail)
	## alias	 help(tkfile.dir)
	## alias	 help(tkopen)
	## alias	 help(tkclose)
	## alias	 help(tkputs)

##___ Examples ___:

##Don't run: 
##D ## These cannot be run by examples() but should be OK when pasted
##D ## into an interactive R session with the tcltk package loaded
##D 
##D tt <- tktoplevel()
##D tkpack(l1<-tklabel(tt,text="Heave"),l2<-tklabel(tt,text="Ho"))
##D tkpack.configure(l1,side="left")
##D 
##D ## Try stretching the window and then
##D 
##D tkdestroy(tt)



## Keywords: 'misc'.


