###--- >>> `NLSstAsymptotic' <<<----- Fit the Asymptotic Regression Model

	## alias	 help(NLSstAsymptotic)
	## alias	 help(NLSstAsymptotic.sortedXyData)

##___ Examples ___:

data( Loblolly )
Lob.329 <- Loblolly[ Loblolly$Seed == "329", ]
NLSstAsymptotic(sortedXyData(expression(age), expression(height), Lob.329 ))

## Keywords: 'manip'.


