###--- >>> `identical' <<<----- Test Objects for Exact Equality

	## alias	 help(identical)

##___ Examples ___:

identical(1, NULL) ## FALSE -- don't try this with ==
identical(1, 1.)   ## TRUE in R (both are stored as doubles)
identical(1, as.integer(1)) ## FALSE, stored as different types
x <- 1.; y <- .99999999999
## how to test for object equality allowing for numeric fuzz
identical(all.equal(x, y), TRUE)
## If all.equal thinks the objects are different, it returns a
## character string, and this expression evaluates to FALSE

## Keywords: 'programming', 'logic', 'iteration'.


