###--- >>> `traceback' <<<----- Print Call Stack of Last Error

	## alias	 help(traceback)
	## alias	 help(.Traceback)

##___ Examples ___:

foo <- function(x) { print(1); bar(2) }
bar <- function(x) { x + a.variable.which.does.not.exist }
##Don't run: 
##D foo(2) # gives a strange error
##D traceback()
## 2: bar(2)
## 1: foo(2)
bar
## Ah, this is the culprit ...

## Keywords: 'programming'.


