###--- >>> `GammaDist' <<<----- The Gamma Distribution

	## alias	 help(dgamma)
	## alias	 help(pgamma)
	## alias	 help(qgamma)
	## alias	 help(rgamma)

##___ Examples ___:

-log(dgamma(1:4, shape=1))
p <- (1:9)/10
pgamma(qgamma(p,shape=2), shape=2)
1 - 1/exp(qgamma(p, shape=1))

## Keywords: 'distribution'.


