###--- >>> `getInitial' <<<----- Get Initial Parameter Estimates

	## alias	 help(getInitial)
	## alias	 help(getInitial.default)
	## alias	 help(getInitial.formula)
	## alias	 help(getInitial.selfStart)

##___ Examples ___:

data(Puromycin)
PurTrt <- Puromycin[ Puromycin$state == "treated", ]
getInitial( rate ~ SSmicmen( conc, Vm, K ), PurTrt )

## Keywords: 'models', 'nonlinear', 'manip'.


