###--- >>> `USArrests' <<<----- Violent Crime Rates by US State

	## alias	 help(USArrests)

##___ Examples ___:

data(USArrests)
pairs(USArrests, panel = panel.smooth, main = "USArrests data")

## Keywords: 'datasets'.


