###--- >>> `var.test' <<<----- F Test to Compare Two Variances

	## alias	 help(var.test)
	## alias	 help(var.test.default)
	## alias	 help(var.test.formula)

##___ Examples ___:

x <- rnorm(50, mean = 0, sd = 2)
y <- rnorm(30, mean = 1, sd = 1)
var.test(x, y)                  # Do x and y have the same variance?
var.test(lm(x ~ 1), lm(y ~ 1))  # The same.

## Keywords: 'htest'.


