###--- >>> `time' <<<----- Sampling Times of Time Series

	## alias	 help(time)
	## alias	 help(cycle)
	## alias	 help(frequency)
	## alias	 help(deltat)
	## alias	 help(time.default)
	## alias	 help(time.ts)
	## alias	 help(cycle.default)
	## alias	 help(cycle.ts)
	## alias	 help(frequency.default)
	## alias	 help(deltat.default)

##___ Examples ___:

data(presidents)
cycle(presidents)
# a simple series plot: c() makes the x and y arguments into vectors
plot(c(time(presidents)), c(presidents), type="l")

## Keywords: 'ts'.


