###--- >>> `pushBack' <<<----- Push Text Back on to a Connection

	## alias	 help(pushBack)
	## alias	 help(pushBackLength)

##___ Examples ___:

zz <- textConnection(LETTERS)
readLines(zz, 2)
pushBack(c("aa", "bb"), zz)
pushBackLength(zz)
readLines(zz, 1)
pushBackLength(zz)
readLines(zz, 1)
readLines(zz, 1)
close(zz)

## Keywords: 'connection'.


