###--- >>> `crossprod' <<<----- Matrix Crossproduct

	## alias	 help(crossprod)

##___ Examples ___:

(z <- crossprod(1:4))    # = sum(1 + 2^2 + 3^2 + 4^2)
drop(z)                  # scalar

## Keywords: 'algebra', 'array'.


