###--- >>> `name' <<<----- Variable Names or Symbols, respectively

	## alias	 help(name)
	## alias	 help(is.symbol)
	## alias	 help(as.symbol)
	## alias	 help(as.name)
	## alias	 help(is.name)

##___ Examples ___:

an <- as.name("arrg")
is.name(an) # TRUE
str(an)# symbol

## Keywords: 'programming', 'attribute'.


