###--- >>> `Sys.time' <<<----- Get Current Time and Timezone

	## alias	 help(Sys.time)
	## alias	 help(Sys.timezone)

##___ Examples ___:

Sys.time()
## locale-specific version of date()
format(Sys.time(), "%a %b %d %X %Y")

Sys.timezone()

## Keywords: 'utilities', 'chron'.


