###--- >>> `sunspot' <<<----- Yearly Sunspot Data, 1700-1988. Monthly Sunspot Data, 1749-1997.

	## alias	 help(sunspot)
	## alias	 help(sunspot.month)
	## alias	 help(sunspot.year)

##___ Examples ___:

## Compare the monthly series from 'base' and 'ts':
data(sunspots, package = base)
data(sunspot,  package = ts)
plot (sunspot.month, main = "sunspot.month [ts]", col = 2)
lines(sunspots)# ``very barely'' see something

## Now look at the difference :
all(tsp(sunspots)     [c(1,3)] ==
    tsp(sunspot.month)[c(1,3)]) ## Start & Periodicity are the same
n1 <- length(sunspots)
table(eq <- sunspots == sunspot.month[1:n1]) #>  132  are different !
i <- which(!eq) 
rug(time(eq)[i])
s1 <- sunspots[i] ; s2 <- sunspot.month[i]
cbind(i = i, sunspots = s1, ss.month = s2,
      perc.diff = round(100*2*abs(s1-s2)/(s1+s2), 1))

## Keywords: 'datasets'.


