###--- >>> `reg.finalizer' <<<----- Finalization of objects

	## alias	 help(reg.finalizer)

##___ Examples ___:

 f <- function(e) print("cleaning....")
 g <- function(x){e<-environment(); reg.finalizer(e,f)}
 g() 
 gc() # trigger cleanup

## Keywords: 'programming'.


