###--- >>> `Startup' <<<----- Initialization at Start of an R Session

	## alias	 help(Startup)
	## alias	 help(Rprofile)
	## alias	 help(.Rprofile)
	## alias	 help(Rprofile.site)
	## alias	 help(Renviron.site)
	## alias	 help(.Renviron)
	## alias	 help(.First)

##___ Examples ___:

##Don't run: ## Some examples with a Unix flavour
##D # ~/.Renviron
##D R_LIBS=~/R/library
##D PAGER=/usr/local/bin/less
##D 
##D # .Rprofile
##D options(width=65, digits=5)
##D options(show.signif.stars=FALSE)
##D ps.options(horizontal=FALSE)
##D set.seed(1234)
##D .First <- function() cat("\n   Welcome to R!\n\n")
##D .Last <- function()  cat("\n   Goodbye!\n\n")
##D 
##D ## if .Renviron contains
##D FOOBAR="coo\bar"doh\ex"abc\"def'"
##D 
##D ## then we get
##D > cat(Sys.getenv("FOOBAR"), "\n")
##D coo\bardoh\exabc"def'

## Keywords: 'environment'.


