###--- >>> `assign' <<<----- Assign a Value to a Name

	## alias	 help(assign)
	## alias	 help(<-)
	## alias	 help(=)
	## alias	 help(<<-)
	## alias	 help(->)
	## alias	 help(->>)

##___ Examples ___:

for(i in 1:6) { #-- Create objects  'r1', 'r2', ... 'r6' --
 nam <- paste("r",i, sep=".")
 assign(nam, 1:i)
}
ls(pat="^r..$")

##-- Global assignment within a function:
myf <- function(x) {
 innerf <- function(x) assign("Global.res", x^2, env = .GlobalEnv)
 innerf(x+1)
}
myf(3)
Global.res # 16

a<-1:4
assign("a[1]",2)
a[1]==2          #FALSE
get("a[1]")==2   #TRUE


## Keywords: 'data'.


