###--- >>> `factor.scope' <<<----- Compute Allowed Changes in Adding to or Dropping from a Formula

	## alias	 help(add.scope)
	## alias	 help(drop.scope)
	## alias	 help(factor.scope)

##___ Examples ___:

add.scope( ~ a + b + c + a:b,  ~ (a + b + c)^3)
# [1] "a:c" "b:c"
drop.scope( ~ a + b + c + a:b)
# [1] "c"   "a:b"

## Keywords: 'models'.


