###--- >>> `data.class' <<<----- Object Classes

	## alias	 help(data.class)

##___ Examples ___:

x <- LETTERS
data.class(factor(x))                 # has a class attribute
data.class(matrix(x, nc = 13))        # has a dim attribute
data.class(list(x))                   # the same as mode(x)
data.class(x)                         # the same as mode(x)

## Keywords: 'classes', 'methods'.


