###--- >>> `showConnections' <<<----- Display Connections

	## alias	 help(showConnections)
	## alias	 help(getConnection)
	## alias	 help(getAllConnections)
	## alias	 help(closeAllConnections)
	## alias	 help(stdin)
	## alias	 help(stdout)
	## alias	 help(stderr)

##___ Examples ___:

showConnections(all = TRUE)

textConnection(letters)
# oops, I forgot to record that one
showConnections()
#  class     description      mode text   isopen   can read can write
#3 "letters" "textConnection" "r"  "text" "opened" "yes"    "no"     
##Don't run: close(getConnection(3))
r <- as.numeric(row.names(showConnections()))
close(getConnection(r))
showConnections()

## Keywords: 'connection'.


