###--- >>> `summary' <<<----- Object Summaries

	## alias	 help(summary)
	## alias	 help(summary.default)
	## alias	 help(summary.data.frame)
	## alias	 help(summary.factor)
	## alias	 help(summary.matrix)

##___ Examples ___:

data(attenu)
summary(attenu, digits = 4) #-> summary.data.frame(...), default precision
summary(attenu $ station, maxsum = 20) #-> summary.factor(...)

## Keywords: 'methods'.


