###--- >>> `grid' <<<----- Add Grid to a Plot

	## alias	 help(grid)

##___ Examples ___:

data(iris)
## maybe change the desired number of tick marks:  par(lab=c(mx,my,7))
plot(iris$Sepal.L, iris$Sepal.W, col = rep(1:3, rep(50, 3)),
     xlim = c(4, 8), ylim = c(2, 4.5), panel.first = grid())

## Keywords: 'aplot'.


