###--- >>> `unique' <<<----- Extract Unique Elements

	## alias	 help(unique)
	## alias	 help(unique.default)
	## alias	 help(unique.data.frame)

##___ Examples ___:

unique(c(3:5, 11:8, 8 + 0:5))
length(unique(sample(100, 100, replace=TRUE)))
## approximately 100(1 - 1/e) = 63.21
my.unique <- function(x) x[!duplicated(x)]
for(i in 1:4)
 { x <- rpois(100, pi); stopifnot(unique(x) == my.unique(x)) }

data(iris)
unique(iris)
stopifnot(dim(unique(iris)) == c(149, 5))

## Keywords: 'manip', 'logic'.


