###--- >>> `reshapeWide-deprecated' <<<----- Reshape data frame to wide format

	## alias	 help(reshapeWide-deprecated)

##___ Examples ___:

dd<-as.data.frame(matrix(1:24,4))
(dd1<-reshapeLong(dd,V3:V5))
reshapeWide(dd1)
reshapeWide(dd1,jnames=c("A","B","C"))

## Keywords: 'manip'.


