###--- >>> `is.recursive' <<<----- Is an Object Atomic or Recursive?

	## alias	 help(is.atomic)
	## alias	 help(is.recursive)

##___ Examples ___:

is.a.r <- function(x) c(is.atomic(x), is.recursive(x))

is.a.r(c(a=1,b=3))# TRUE FALSE
is.a.r(list())    # FALSE TRUE ??
is.a.r(list(2))   # FALSE TRUE
is.a.r(lm)        #   "
is.a.r(y ~ x)     #   "
is.a.r(expression(x+1))# should be F-T (not in 0.62.3!)

## Keywords: 'programming', 'classes'.


