###--- >>> `Extract' <<<----- Extract or Replace Parts of an Object

	## alias	 help(Extract)
	## alias	 help(Subscript)
	## alias	 help([)
	## alias	 help([[)
	## alias	 help($)
	## alias	 help([<-)
	## alias	 help([[<-)
	## alias	 help($<-)
	## alias	 help([.data.frame)
	## alias	 help([[.data.frame)
	## alias	 help([<-.data.frame)
	## alias	 help([[<-.data.frame)
	## alias	 help([.factor)
	## alias	 help([.formula)
	## alias	 help([.ts)
	## alias	 help([<-.factor)
	## alias	 help([.noquote)
	## alias	 help([<-.noquote)

##___ Examples ___:

x <- 1:12; m <- matrix(1:6,nr=2); li <- list(pi=pi, e = exp(1))
x[10]                 # the tenth element of x
m[1,]                 # the first row of matrix m
m[1, , drop = FALSE]  # is a 1-row matrix
li[[1]]               # the first element of list li
y <- list(1,2,a=4,5)
y[c(3,4)]             # a list containing elements 3 and 4 of y
y$a                   # the element of y named a

data(swiss)
swiss[ c(1, 1:2), ]   # duplicate row, unique row names

## Keywords: 'array', 'list'.


