###--- >>> `median' <<<----- Median Value

	## alias	 help(median)

##___ Examples ___:

median(1:4)# = 2.5 [even number]
median(c(1:3,100,1000))# = 3 [odd, robust]

## Keywords: 'univar', 'robust'.


