###--- >>> `file.access' <<<----- Ascertain File Accessibility

	## alias	 help(file.access)

##___ Examples ___:

fa <- file.access(dir("."))
table(fa) # count successes & failures

## Keywords: 'file'.


