###--- >>> `numeric' <<<----- Numeric Vectors

	## alias	 help(numeric)
	## alias	 help(as.numeric)
	## alias	 help(is.numeric)

##___ Examples ___:

as.numeric(c("-.1"," 2.7 ","B")) # (-0.1, 2.7, NA)  +  warning
as.numeric(factor(5:10))

## Keywords: 'classes', 'attribute'.


