###--- >>> `sweep' <<<----- Sweep out Array Summaries

	## alias	 help(sweep)

##___ Examples ___:

data(attitude)
med.att <- apply(attitude, 2, median)
sweep(data.matrix(attitude), 2, med.att)# subtract the column medians

## Keywords: 'array', 'iteration'.


