###--- >>> `dump' <<<----- Text Representations of R Objects

	## alias	 help(dump)

##___ Examples ___:

x <- 1; y <- 1:10
dump(ls(patt='^[xyz]'), "xyz.Rdmped")
unlink("xyz.Rdmped")

## Keywords: 'file', 'connection'.


