###--- >>> `warning' <<<----- Warning Messages

	## alias	 help(warning)

##___ Examples ___:

eigenval <- 10 ^ -rnorm(1,m=6)
if(eigenval < 1.e-7) warning("system near singular")

## Keywords: 'programming', 'error'.


