###--- >>> `sequence' <<<----- Create A Vector of Sequences

	## alias	 help(sequence)

##___ Examples ___:

sequence(c(3,2))# the concatenated sequences 1:3 and 1:2.
#> [1] 1 2 3 1 2

## Keywords: 'manip'.


