###--- >>> `all.equal' <<<----- Test if Two Objects are (Nearly) Equal

	## alias	 help(all.equal)
	## alias	 help(all.equal.default)
	## alias	 help(all.equal.numeric)
	## alias	 help(all.equal.character)
	## alias	 help(all.equal.factor)
	## alias	 help(all.equal.formula)
	## alias	 help(all.equal.list)
	## alias	 help(all.equal.language)
	## alias	 help(attr.all.equal)

##___ Examples ___:

all.equal(pi, 355/113) # not precise enough (default tol) > relative error

stopifnot(
all.equal(gamma(2:14),   cumprod(1:13))) # TRUE, but

all      (gamma(2:14) == cumprod(1:13)) # FALSE, since not exactly
all.equal(gamma(2:14),   cumprod(1:13), tol=0) # to see difference

all.equal(options(), .Options)
all.equal(options(), as.list(.Options))# TRUE
.Options $ myopt <- TRUE
all.equal(options(), as.list(.Options))
rm(.Options)

## Keywords: 'utilities', 'logic', 'arith'.


