###--- >>> `Harman74.cor' <<<----- Harman Example 7.4

	## alias	 help(Harman74.cor)

##___ Examples ___:

data(Harman74.cor)
(Harman74.FA <- factanal(factors = 1, covmat = Harman74.cor))
for(factors in 2:5) print(update(Harman74.FA, factors = factors))
Harman74.FA <- factanal(factors = 5, covmat = Harman74.cor,
                        rotation="promax")
print(Harman74.FA$loadings, sort = TRUE)

## Keywords: 'datasets'.


