###--- >>> `ks.test' <<<----- Kolmogorov-Smirnov Tests

	## alias	 help(ks.test)

##___ Examples ___:

x <- rnorm(50)
y <- runif(30)
# Do x and y come from the same distribution?
ks.test(x, y)
# Does x come from a shifted gamma distribution with shape 3 and scale 2?
ks.test(x+2, "pgamma", 3, 2) # two-sided
ks.test(x+2, "pgamma", 3, 2, alternative = "gr")

## Keywords: 'htest'.


