###--- >>> `Last.value' <<<----- Value of Last Evaluated Expression

	## alias	 help(.Last.value)

##___ Examples ___:

## These will not work correctly from example(),
## but they will in make check or if pasted in,
## as example() does not run them at the top level
gamma(1:15)          # think of some intensive calculation...
fac14 <- .Last.value # keep them

library("eda") # returns invisibly
.Last.value    # shows what library(.) above returned
detach("package:eda")

## Keywords: 'programming'.


