###--- >>> `url.show' <<<----- Display a text URL

	## alias	 help(url.show)

##___ Examples ___:

##Don't run: url.show("http://lib.stat.cmu.edu/datasets/csb/ch3a.txt")

## Keywords: 'file', 'misc'.


