###--- >>> `help' <<<----- Documentation

	## alias	 help(help)
	## alias	 help(?)

##___ Examples ___:

help()
help(help)              # the same

help(lapply)
?lapply                 # the same

help("for")             # or ?"for", but the quotes are needed
?"+"

help(package = stepfun) # get help even when package is not loaded

data()                  # list all available data sets
?women                  # information about data set "women"

topi <- "women"
##Don't run: help(topi) ##--> Error: No documentation for `topi'

try(help("bs", try.all.packages=FALSE)) # reports not found (an error)
help("bs", try.all.packages=TRUE) # reports can be found in package `splines'

## Keywords: 'documentation'.


