###--- >>> `mood.test' <<<----- Mood Two-Sample Test of Scale

	## alias	 help(mood.test)
	## alias	 help(mood.test.default)
	## alias	 help(mood.test.formula)

##___ Examples ___:

## Same data as for the Ansari-Bradley test:
## Serum iron determination using Hyland control sera
ramsay <- c(111, 107, 100, 99, 102, 106, 109, 108, 104, 99,
            101, 96, 97, 102, 107, 113, 116, 113, 110, 98)
jung.parekh <- c(107, 108, 106, 98, 105, 103, 110, 105, 104,
            100, 96, 108, 103, 104, 114, 114, 113, 108, 106, 99)
mood.test(ramsay, jung.parekh)
## Compare this to ansari.test(ramsay, jung.parekh)

## Keywords: 'htest'.


