###--- >>> `ns' <<<----- Generate a Basis Matrix for Natural Cubic Splines

	## alias	 help(ns)

##___ Examples ___:

data(women)
ns(women$height, df = 5)
summary(fm1 <- lm(weight ~ ns(height, df = 5), data = women))

## Keywords: 'smooth'.


