###--- >>> `sample' <<<----- Random Samples and Permutations

	## alias	 help(sample)

##___ Examples ___:

x <- 1:12
# a random permutation
sample(x)
# bootstrap sampling
sample(x,replace=TRUE)

# 100 Bernoulli trials
sample(c(0,1), 100, replace = TRUE)

## Keywords: 'distribution'.


