###--- >>> `t.test' <<<----- Student's t-Test

	## alias	 help(t.test)
	## alias	 help(t.test.default)
	## alias	 help(t.test.formula)

##___ Examples ___:

t.test(1:10,y=c(7:20))      # P = .00001855
t.test(1:10,y=c(7:20, 200)) # P = .1245    -- NOT significant anymore

## Classical example: Student's sleep data
data(sleep)
plot(extra ~ group, data = sleep)
## Traditional interface
attach(sleep)
t.test(extra[group == 1], extra[group == 2])
detach()
## Formula interface
t.test(extra ~ group, data = sleep)

## Keywords: 'htest'.


