###--- >>> `as.environment' <<<----- Coerce to an Environment Object

	## alias	 help(as.environment)

##___ Examples ___:

as.environment(1) ## the global environment
identical(globalenv(), as.environment(1)) ## is TRUE
as.environment("package:ctest")

## Keywords: 'data', 'environment'.


