###--- >>> `Beta' <<<----- The Beta Distribution

	## alias	 help(dbeta)
	## alias	 help(pbeta)
	## alias	 help(qbeta)
	## alias	 help(rbeta)

##___ Examples ___:

x <- seq(0, 1, length=21)
dbeta(x, 1, 1)
pbeta(x, 1, 1)

## Keywords: 'distribution'.


