###--- >>> `class' <<<----- Object Classes

	## alias	 help(class)
	## alias	 help(class<-)
	## alias	 help(unclass)
	## alias	 help(inherits)

##___ Examples ___:

  x <- 10
  inherits(x, "a") #FALSE
  class(x)<-c("a", "b")
  inherits(x,"a") #TRUE
  inherits(x, "a", TRUE) # 1
  inherits(x, c("a", "b", "c"), TRUE) # 1 2 0

## Keywords: 'methods', 'classes'.


