###--- >>> `dyn.load' <<<----- Foreign Function Interface

	## alias	 help(dyn.load)
	## alias	 help(dyn.unload)
	## alias	 help(is.loaded)
	## alias	 help(symbol.C)
	## alias	 help(symbol.For)

##___ Examples ___:

is.loaded(symbol.For("hcass2")) #-> probably  FALSE
library(mva)
is.loaded(symbol.For("hcass2")) #-> TRUE
detach("package:mva")

## Keywords: 'interface'.


