###--- >>> `logLik' <<<----- Extract Log-Likelihood

	## alias	 help(logLik)
	## alias	 help(print.logLik)
	## alias	 help(str.logLik)
	## alias	 help(as.data.frame.logLik)

##___ Examples ___:

## see the method function documentation
x <- 1:5
lmx <- lm(x ~ 1)
logLik(lmx) # using print.logLik() method
str(logLik(lmx))

## Keywords: 'models'.


