###--- >>> `Harman23.cor' <<<----- Harman Example 2.3

	## alias	 help(Harman23.cor)

##___ Examples ___:

data(Harman23.cor)
(Harman23.FA <- factanal(factors = 1, covmat = Harman23.cor))
for(factors in 2:4) print(update(Harman23.FA, factors = factors))

## Keywords: 'datasets'.


