###--- >>> `system' <<<----- Invoke a System Command

	## alias	 help(system)
	## alias	 help(unix)

##___ Examples ___:

# list all files in the current directory using the -F flag
##Don't run: system("ls -F")

# t1 is a character vector, each one
# representing a separate line of output from who
t1 <- system("who", TRUE)

system("ls fizzlipuzzli", TRUE, TRUE)# empty since file doesn't exist

## Keywords: 'interface', 'file', 'utilities'.


