###--- >>> `NA' <<<----- Not Available / ``Missing'' Values

	## alias	 help(NA)
	## alias	 help(is.na)
	## alias	 help(is.na.data.frame)
	## alias	 help(is.na<-)
	## alias	 help(is.na<-.default)

##___ Examples ___:

is.na(c(1,NA))       #> F TRUE
is.na(paste(c(1,NA)))#> F FALSE

 is.na(list())# logical(0)
 ll <- list(pi,"C",NaN,Inf, 1:3, c(0,NA), NA)
 is.na (ll)
 is.nan(ll)


## Keywords: 'NA', 'logic', 'manip'.


