###--- >>> `menu' <<<----- Menu Interaction Function

	## alias	 help(menu)

##___ Examples ___:

##Don't run: 
##D switch(menu(c("List letters", "List LETTERS")) + 1,
##D        cat("Nothing done\n"), letters, LETTERS)


## Keywords: 'utilities', 'programming'.


