###--- >>> `rep' <<<----- Replicate Elements of Vectors and Lists

	## alias	 help(rep)

##___ Examples ___:

rep(1:4, 2)
rep(1:4, c(2,2,2,2))     # same as above, length 8.
rep(1:4, c(2,1,2,1))
rep(1:4, c(2,2,2,2), 4)  # first 4 only.
rep(1:4, c(2,2,2,2), 10) # 8 intgers plus two NAs

rep(1, 40*(1-.8)) # length 7 on most platforms
rep(1, 40*(1-.8)+1e-7) # better

## replicate a list
fred <- list(happy = 1:10, name = "squash")
rep(fred, 5)

## Keywords: 'manip'.


