###--- >>> `assocplot' <<<----- Association Plots

	## alias	 help(assocplot)

##___ Examples ___:

data(HairEyeColor)
## Aggregate over sex:
x <- margin.table(HairEyeColor, c(1, 2))
x
assocplot(x, main = "Relation between hair and eye color")

## Keywords: 'hplot'.


