###--- >>> `predict.nls' <<<----- Predicting from Nonlinear Least Squares Fits

	## alias	 help(predict.nls)

##___ Examples ___:

data( BOD )
fm <- nls(demand ~ SSasympOrig(Time, A, lrc), data = BOD)
predict(fm)              # fitted values at observed times
## Form data plot and smooth line for the predictions
opar <- par(las = 1)
plot(demand ~ Time, data = BOD, col = 4,
     main = "BOD data and fitted first-order curve",
     xlim = c(0,7), ylim = c(0, 20) )
tt <- seq(0, 8, length = 101)
lines(tt, predict(fm, list(Time = tt)))
par(opar)

## Keywords: 'nonlinear', 'regression', 'models'.


