###--- >>> `plot.formula' <<<----- Formula Notation for Scatterplots

	## alias	 help(plot.formula)
	## alias	 help(lines.formula)
	## alias	 help(points.formula)

##___ Examples ___:

data(airquality)
op <- par(mfrow=c(2,1))
plot(Ozone ~ Wind, data = airquality, pch=as.character(Month))
plot(Ozone ~ Wind, data = airquality, pch=as.character(Month),
     subset = Month != 7)
par(op)

## Keywords: 'hplot'.


