###--- >>> `LifeCycleSavings' <<<----- Intercountry Life-Cycle Savings Data

	## alias	 help(LifeCycleSavings)

##___ Examples ___:

data(LifeCycleSavings)
pairs(LifeCycleSavings, panel = panel.smooth,
      main = "LifeCycleSavings data")
fm1 <- lm(sr ~ pop15 + pop75 + dpi + ddpi, data = LifeCycleSavings)
summary(fm1)

## Keywords: 'datasets'.


