###--- >>> `palette' <<<----- Set or View the Graphics Palette

	## alias	 help(palette)

##___ Examples ___:

palette()               # obtain the current palette
palette(rainbow(6))     # six color rainbow

(palette(gray(seq(0,.9,len=25)))) # gray scales; print old palette
matplot(outer(1:100,1:30), type='l', lty=1,lwd=2, col=1:30,
        main = "Gray Scales Palette",
        sub = "palette(gray(seq(0,.9,len=25)))")
palette("default")      # reset back to the default

## Keywords: 'color', 'sysdata'.


