###--- >>> `weekdays' <<<----- Extract Parts of a POSIXt Object

	## alias	 help(weekdays)
	## alias	 help(weekdays.POSIXt)
	## alias	 help(months)
	## alias	 help(months.POSIXt)
	## alias	 help(quarters)
	## alias	 help(quarters.POSIXt)
	## alias	 help(julian)
	## alias	 help(julian.POSIXt)

##___ Examples ___:

weekdays(.leap.seconds)
months(.leap.seconds)
quarters(.leap.seconds)

## Keywords: 'chron'.


