###--- >>> `split' <<<----- Divide into Groups

	## alias	 help(split)
	## alias	 help(split.default)
	## alias	 help(split.data.frame)

##___ Examples ___:

n <- 10; nn <- 100
g <- factor(round(n * runif(n * nn)))
x <- rnorm(n * nn) + sqrt(as.numeric(g))
xg <- split(x, g)
boxplot(xg, col = "lavender", notch = TRUE, varwidth = TRUE)
sapply(xg, length)
sapply(xg, mean)

## Split a matrix into a list by columns
ma <- cbind(x = 1:10, y = (-4:5)^2)
split(ma, col(ma))

split(1:10, 1:2)

## Keywords: 'category'.


