###--- >>> `Recall' <<<----- Recursive Calling

	## alias	 help(Recall)

##___ Examples ___:

## A trivial (but inefficient!) example:
fib <- function(n) if(n<=2) {if(n>=0) 1 else 0} else Recall(n-1) + Recall(n-2)
fibonacci <- fib; rm(fib)
## renaming wouldn't work without Recall
fibonacci(10) # 55

## Keywords: 'programming'.


