###--- >>> `Sys.sleep' <<<----- Suspend Execution for a Time Interval

	## alias	 help(Sys.sleep)

##___ Examples ___:

testit <- function(x)
{
    p1 <- proc.time()
    Sys.sleep(x)
    proc.time() - p1 # The cpu usage should be negligible
}
testit(3.7)

## Keywords: 'utilities'.


