###--- >>> `t' <<<----- Matrix Transpose

	## alias	 help(t)
	## alias	 help(t.default)
	## alias	 help(t.data.frame)

##___ Examples ___:

a <- matrix(1:30, 5,6)
ta <- t(a) ##-- i.e.,  a[i, j] == ta[j, i] for all i,j :
for(j in seq(ncol(a)))
  if(! a[, j] == ta[j, ]) stop("wrong transpose")

## Keywords: 'array'.


