###--- >>> `quakes' <<<----- Locations of Earthquakes off Fiji

	## alias	 help(quakes)

##___ Examples ___:

data(quakes)
pairs(quakes, main = "Fiji Earthquakes, N = 1000", cex.main=1.2, pch=".")

## Keywords: 'datasets'.


