###--- >>> `Logic' <<<----- Logical Operators

	## alias	 help(!)
	## alias	 help(&)
	## alias	 help(&&)
	## alias	 help(|)
	## alias	 help(||)
	## alias	 help(xor)
	## alias	 help(Logic)

##___ Examples ___:

y <- 1 + (x <- rpois(50, lambda=1.5) / 4 - 1)
x[(x > 0) & (x < 1)]    # all x values between 0 and 1
if (any(x == 0) || any(y == 0)) "zero encountered"

## Keywords: 'logic'.


