###--- >>> `data' <<<----- Data Sets

	## alias	 help(data)
	## alias	 help(print.packageIQR)

##___ Examples ___:

data()                      # list all available data sets
data(package = base)        # list the data sets in the base package
data(USArrests, "VADeaths") # load the data sets `USArrests' and `VADeaths'
help(USArrests)             # give information on data set `USArrests'

## Keywords: 'documentation', 'datasets'.


