###--- >>> `plot.factor' <<<----- Plotting Factor Variables

	## alias	 help(plot.factor)

##___ Examples ___:

data(PlantGrowth)
plot(PlantGrowth)                                # -> plot.data.frame
plot(weight ~ group, data = PlantGrowth)         # numeric vector ~ factor
plot(cut(weight, 2) ~ group, data = PlantGrowth) # factor ~ factor

plot(PlantGrowth$group, axes=FALSE, main="no axes")# extremly silly

## Keywords: 'hplot'.


