###--- >>> `duplicated' <<<----- Determine Duplicate Elements

	## alias	 help(duplicated)
	## alias	 help(duplicated.default)
	## alias	 help(duplicated.data.frame)

##___ Examples ___:

x <- c(9:20, 1:5, 3:7, 0:8)
## extract unique elements
(xu <- x[!duplicated(x)])
stopifnot(xu == unique(x), # but unique(x) is more efficient
          0:20 == sort(x[!duplicated(x)]))

data(iris)
stopifnot(duplicated(iris)[143] == TRUE)

## Keywords: 'logic', 'manip'.


