###--- >>> `pictex' <<<----- A PicTeX Graphics Driver

	## alias	 help(pictex)

##___ Examples ___:

pictex()
plot(1:11,(-5:5)^2, type='b', main="Simple Example Plot")
dev.off()
##--------------------
##Don't run: 
##D %% LaTeX Example
##D \documentclass{article}
##D \usepackage{pictex}
##D \begin{document}
##D %...
##D \begin{figure}[h]
##D   \centerline{\input{Rplots.tex}}
##D   \caption{}
##D \end{figure}
##D %...
##D \end{document}
##D 
##D %%-- TeX Example --
##D \input pictex
##D $$ \input Rplots.tex $$

##--------------------
unlink("Rplots.tex")

## Keywords: 'device'.


