###--- >>> `airquality' <<<----- New York Air Quality Measurements

	## alias	 help(airquality)

##___ Examples ___:

data(airquality)
pairs(airquality, panel = panel.smooth, main = "airquality data")

## Keywords: 'datasets'.


