###--- >>> `Paren' <<<----- Parentheses and Braces

	## alias	 help(()

##___ Examples ___:

f <- get("(")
e <- expression(3 + 2 * 4)
f(e) == e           # TRUE

do <- get("{")
do(x <- 3, y <- 2*x-3, 6-x-y); x; y

## Keywords: 'programming'.


