###--- >>> `double' <<<----- Double Precision Vectors

	## alias	 help(double)
	## alias	 help(as.double)
	## alias	 help(as.double.default)
	## alias	 help(is.double)
	## alias	 help(single)
	## alias	 help(as.single)
	## alias	 help(as.single.default)

##___ Examples ___:

is.double(1)
all(double(3) == 0)

## Keywords: 'classes'.


