###--- >>> `ability.cov' <<<----- Ability and Intelligence Tests

	## alias	 help(ability.cov)

##___ Examples ___:

data(ability.cov)
(ability.FA <- factanal(factors = 1, covmat=ability.cov))
update(ability.FA, factors=2)
update(ability.FA, factors=2, rotation="promax")

## Keywords: 'datasets'.


