###--- >>> `volcano' <<<----- Topographic Information for the Maunga Whau Volcano

	## alias	 help(volcano)

##___ Examples ___:

data(volcano)
filled.contour(volcano, color = terrain.colors, asp = 1)
title(main = "volcano data: filled contour map")

## Keywords: 'datasets'.


