###--- >>> `MethodsList' <<<----- MethodsList Objects

	## alias	 help(MethodsList)
	## alias	 help(makeMethodsList)
	## alias	 help(SignatureMethod)
	## alias	 help(insertMethod)
	## alias	 help(matchArg)
	## alias	 help(matchArgClass)
	## alias	 help(showMlist)
	## alias	 help(print.MethodsList)
	## alias	 help(emptyMethodsList)
	## alias	 help(insertMethodInEmptyList)
	## alias	 help(listFromMlist)
	## alias	 help(linearizeMlist)
	## alias	 help(finalDefaultMethod)
	## alias	 help(mergeMethods)

##___ Examples ___:


## Keywords: 'internal'.


