###--- >>> `randu' <<<----- Random Numbers from Congruential Generator

	## alias	 help(randu)

##___ Examples ___:

##Don't run: ## We could re-generate the dataset by the following R code
##D seed <- as.double(1)
##D RANDU <- function() {
##D     seed <<- ((2^16 + 3) * seed) 
##D     seed/(2^31)
##D }
##D for(i in 1:400) {
##D     U <- c(RANDU(), RANDU(), RANDU(), RANDU(), RANDU())
##D     print(round(U[1:3], 6))
##D }

## Keywords: 'datasets'.


