###--- >>> `getClass' <<<----- Get Class Definition

	## alias	 help(getClass)
	## alias	 help(getClassDef)

##___ Examples ___:

getClass("numeric") ## a built in class


getClass("thisIsAnUndefinedClass", .Force = TRUE) ## returns NULL
try(getClass("thisIsAnUndefinedClass")) ## generates an error
try(getClassDef("thisIsAnUndefinedClass")) ## generates an error


## Keywords: 'programming', 'classes'.


