###--- >>> `lm.summaries' <<<----- Accessing Linear Model Fits

	## alias	 help(coefficients.lm)
	## alias	 help(family.lm)
	## alias	 help(formula.lm)
	## alias	 help(fitted.values.lm)
	## alias	 help(residuals.lm)
	## alias	 help(weights)
	## alias	 help(weights.lm)
	## alias	 help(weights.default)

##___ Examples ___:

example("lm", echo = FALSE)
##-- Continuing the  lm(.) example:
coef(lm.D90)# the bare coefficients

## The 2 basic regression diagnostic plots [plot.lm(.) is preferred]
plot(resid(lm.D90), fitted(lm.D90))# Tukey-Anscombe's
abline(h=0, lty=2, col = 'gray')

qqnorm(residuals(lm.D90))

## Keywords: 'regression', 'models'.


