###--- >>> `edit.data.frame' <<<----- Edit Data Frames and Matrices

	## alias	 help(edit.data.frame)
	## alias	 help(edit.matrix)

##___ Examples ___:

##Don't run: 
##D data(InsectSprays)
##D edit(InsectSprays)
##D edit(InsectSprays, factor.mode="numeric")


## Keywords: 'utilities'.


