###--- >>> `nchar' <<<----- Count the Number of Characters

	## alias	 help(nchar)

##___ Examples ___:

x<-c("asfef","qwerty","yuiop[","b","stuff.blah.yech")
nchar(x)
# 5  6  6  1 15

nchar(deparse(mean))
# 23  1 16 45 11 64  2 17 50 43  2 17  1

## Keywords: 'character'.


