###--- >>> `USPersonalExpenditure' <<<----- Personal Expenditure Data

	## alias	 help(USPersonalExpenditure)

##___ Examples ___:

data(USPersonalExpenditure)
USPersonalExpenditure
require(eda)
medpolish(log10(USPersonalExpenditure))

## Keywords: 'datasets'.


