###--- >>> `autoload' <<<----- On-demand Loading of Packages

	## alias	 help(autoload)
	## alias	 help(autoloader)
	## alias	 help(.AutoloadEnv)

##___ Examples ___:

autoload("line","eda")
search()
ls("Autoloads")
all(ls("Autoloads") == ls(envir = .AutoloadEnv))
data(cars)
plot(cars)
z<-line(cars)
abline(coef(z))
search()
detach("package:eda")
search()
z<-line(cars)
search()

## Keywords: 'data', 'programming'.


