###--- >>> `oneway.test' <<<----- Test for Equal Means in a One-Way Layout

	## alias	 help(oneway.test)

##___ Examples ___:

data(sleep)
## Not assuming equal variances
oneway.test(extra ~ group, data = sleep)
## Assuming equal variances
oneway.test(extra ~ group, data = sleep, var.equal = TRUE)
## which gives the same result as
anova(lm(extra ~ group, data = sleep))

## Keywords: 'htest'.


