###--- >>> `glm.summary' <<<----- Summarizing Generalized Linear Model Fits

	## alias	 help(summary.glm)
	## alias	 help(summary.glm.null)
	## alias	 help(print.summary.glm)
	## alias	 help(print.summary.glm.null)

##___ Examples ___:

## --- Continuing the Example from  ``?glm'':
example("glm", echo = FALSE)
summary(glm.D93)

## Keywords: 'models', 'regression'.


