###--- >>> `print' <<<----- Print Values

	## alias	 help(print)
	## alias	 help(print.factor)
	## alias	 help(print.ordered)
	## alias	 help(print.htest)
	## alias	 help(print.listof)
	## alias	 help(print.simple.list)
	## alias	 help(print.table)

##___ Examples ___:

ts(1:20)#-- print  is the ``Default function'' --> print.ts(.) is called
rr <- for(i in 1:3) print(1:i)
rr

## Keywords: 'print'.


