###--- >>> `polyroot' <<<----- Find Zeros of a Real or Complex Polynomial

	## alias	 help(polyroot)

##___ Examples ___:

polyroot(c(1, 2, 1))
round(polyroot(choose(8, 0:8)), 11) # guess what!
for (n1 in 1:4) print(polyroot(1:n1), digits = 4)

## Keywords: 'math'.


