###--- >>> `ChickWeight' <<<----- Weight versus age of chicks on different diets

	## alias	 help(ChickWeight)

##___ Examples ___:

data(ChickWeight)
coplot(weight ~ Time | Chick, data = ChickWeight,
    type = "b", show = FALSE)
## fit a representative chick
fm1 <- nls(weight ~ SSlogis( Time, Asym, xmid, scal ),
    data = ChickWeight, subset = Chick == 1)
summary( fm1 )

## Keywords: 'datasets'.


