###--- >>> `lqs' <<<----- Resistant Regression

	## alias	 help(lqs)
	## alias	 help(lqs.formula)
	## alias	 help(lqs.default)
	## alias	 help(lmsreg)
	## alias	 help(ltsreg)
	## alias	 help(print.lqs)

##___ Examples ___:

data(stackloss)
set.seed(123)
lqs(stack.loss ~ ., data = stackloss)
lqs(stack.loss ~ ., data = stackloss, method = "S", nsamp = "exact")

## Keywords: 'models', 'robust'.


