###--- >>> `qqnorm' <<<----- Quantile-Quantile Plots

	## alias	 help(qqnorm)
	## alias	 help(qqnorm.default)
	## alias	 help(qqplot)
	## alias	 help(qqline)

##___ Examples ___:

y <- rt(200, df = 5)
qqnorm(y); qqline(y, col = 2)
qqplot(y, rt(300, df = 5))
data(precip)
qqnorm(precip, ylab = "Precipitation [in/yr] for 70 US cities")

## Keywords: 'hplot', 'distribution'.


