###--- >>> `sets' <<<----- Set Operations

	## alias	 help(union)
	## alias	 help(intersect)
	## alias	 help(setdiff)
	## alias	 help(is.element)
	## alias	 help(setequal)

##___ Examples ___:

(x <- c(sort(sample(1:20, 9)),NA))
(y <- c(sort(sample(3:23, 7)),NA))
union(x, y)
intersect(x, y)
setdiff(x, y)
setdiff(y, x)
setequal(x, y)

## True for all possible x & y :
setequal( union(x,y),
          c(setdiff(x,y), intersect(x,y), setdiff(y,x)))

is.element(x, y)# length 10
is.element(y, x)# length  8

## Keywords: 'misc'.


