###--- >>> `complete.cases' <<<----- Find Complete Cases

	## alias	 help(complete.cases)

##___ Examples ___:

data(airquality)
x <- airquality[, -1] # x is a regression design matrix
y <- airquality[,  1] # y is the corresponding response

stopifnot(complete.cases(y) != is.na(y))
ok <- complete.cases(x,y)
sum(!ok) # how many are not "ok" ?
x <- x[ok,]
y <- y[ok]

## Keywords: 'NA', 'logic'.


