###--- >>> `NLSstLfAsymptote' <<<----- Horizontal Asymptote on the Left Side

	## alias	 help(NLSstLfAsymptote)
	## alias	 help(NLSstLfAsymptote.sortedXyData)

##___ Examples ___:

data( DNase )
DNase.2 <- DNase[ DNase$Run == "2", ]
DN.srt <- sortedXyData( expression(log(conc)), expression(density), DNase.2 )
NLSstLfAsymptote( DN.srt )

## Keywords: 'manip'.


