###--- >>> `example' <<<----- Run an Examples Section from the Online Help

	## alias	 help(example)

##___ Examples ___:

example(dbinom)
## force use of the standard package eda:
example("smooth", package="eda", lib.loc=.Library)

## Keywords: 'documentation', 'utilities'.


