###--- >>> `edit' <<<----- Invoke a Text Editor

	## alias	 help(edit)
	## alias	 help(edit.default)
	## alias	 help(vi)
	## alias	 help(emacs)
	## alias	 help(pico)
	## alias	 help(xemacs)
	## alias	 help(xedit)

##___ Examples ___:

##Don't run: 
##D # use xedit on the function mean and assign the changes
##D mean <- edit(mean, editor = "xedit")
##D 
##D # use vi on mean and write the result to file mean.out
##D vi(mean, file = "mean.out")


## Keywords: 'utilities'.


