###--- >>> `lower.tri' <<<----- Lower and Upper Triangular Part of a Matrix

	## alias	 help(lower.tri)
	## alias	 help(upper.tri)

##___ Examples ___:

m2 <- ma <- matrix(1:20, 4, 5)
m2[lower.tri(m2)] <- NA
m2
stopifnot(lower.tri(ma) == !upper.tri(ma, diag=TRUE))

## Keywords: 'array'.


