###--- >>> `gl' <<<----- Generate Factor Levels

	## alias	 help(gl)

##___ Examples ___:

# First control, then treatment:
gl(2,8, label=c("Control","Treat"))
# 20 alternating 1s and 2s
gl(2, 1, 20)
# alternating pairs of 1s and 2s
gl(2, 2, 20)


## Keywords: 'category', 'arith'.


