###--- >>> `count.fields' <<<----- Count the Number of Fields per Line

	## alias	 help(count.fields)

##___ Examples ___:

cat("NAME", "1:John", "2:Paul", file = "foo", sep = "\n")
count.fields("foo", sep = ":")
unlink("foo")

## Keywords: 'file'.


