###--- >>> `noquote' <<<----- Class for ``no quote'' Printing of Strings

	## alias	 help(noquote)
	## alias	 help(print.noquote)
	## alias	 help(as.matrix.noquote)

##___ Examples ___:

letters
nql <- noquote(letters)
nql
nql[1:4] <- "oh"
nql[1:12]

cmp.logical <- function(log.v)
{
  ## Purpose: compact printing of logicals
  log.v <- as.logical(log.v)
  noquote(if(length(log.v)==0)"()" else c(".","|")[1+log.v])
}
cmp.logical(runif(20) > 0.8)

## Keywords: 'print', 'methods', 'utilities'.


