###--- >>> `lapply' <<<----- Apply a Function over a List or Vector

	## alias	 help(lapply)
	## alias	 help(sapply)

##___ Examples ___:

x <- list(a = 1:10, beta = exp(-3:3), logic = c(TRUE,FALSE,FALSE,TRUE))
# compute the list mean for each list element
lapply(x,mean)
# median and quartiles for each list element
lapply(x, quantile, probs = 1:3/4)
sapply(x, quantile)
str(i39 <- sapply(3:9, seq))# list of vectors
sapply(i39, fivenum)

## Keywords: 'iteration', 'list'.


