###--- >>> `princomp' <<<----- Principal Components Analysis

	## alias	 help(princomp)
	## alias	 help(princomp.formula)
	## alias	 help(princomp.default)
	## alias	 help(plot.princomp)
	## alias	 help(print.princomp)
	## alias	 help(predict.princomp)

##___ Examples ___:

## The variances of the variables in the
## USArrests data vary by orders of magnitude, so scaling is appropriate
data(USArrests)
(pc.cr <- princomp(USArrests))  # inappropriate
princomp(USArrests, cor = TRUE) # =^= prcomp(USArrests, scale=TRUE)
## Similar, but different:
## The standard deviations differ by a factor of sqrt(49/50)

summary(pc.cr <- princomp(USArrests, cor = TRUE))
loadings(pc.cr)  ## note that blank entries are small but not zero
plot(pc.cr) # shows a screeplot.
biplot(pc.cr)

## Formula interface
princomp(~ ., data = USArrests, cor = TRUE)
# NA-handling
USArrests[1, 2] <- NA
pc.cr <- princomp(~ ., data = USArrests, na.action=na.exclude, cor = TRUE)
pc.cr$scores

## Keywords: 'multivariate'.


