###--- >>> `new' <<<----- Generate an Object from a Class

	## alias	 help(new)

##___ Examples ___:

## using the definition of class "track" from Classes


setClass("track",
            representation(x="numeric", y="numeric"))
setClass("trackCurve",
            representation("track", smooth = "numeric"))

ydata <- rnorm(10); ysmooth <- 1:10

## a new object with two slots specified
t1 <- new("track", x = seq(along=ydata), y = ydata)

# a new object including an object from a superclass, plus a slot
t2 <- new("trackCurve", t1, smooth = ysmooth)

## Keywords: 'programming', 'classes'.


