###--- >>> `model.extract' <<<----- Extract Components from a Model Frame

	## alias	 help(model.extract)
	## alias	 help(model.offset)
	## alias	 help(model.response)
	## alias	 help(model.weights)

##___ Examples ___:

data(esoph)
a <- model.frame(cbind(ncases,ncontrols) ~ agegp+tobgp+alcgp, data=esoph)
model.extract(a, "response")
stopifnot(model.extract(a, "response") == model.response(a))

a <- model.frame(ncases/(ncases+ncontrols) ~ agegp+tobgp+alcgp,
                 data = esoph, weights = ncases+ncontrols)
model.response(a)
model.extract(a, "weights")

a <- model.frame(cbind(ncases,ncontrols) ~ agegp,
                 something = tobgp, data = esoph)
names(a)
stopifnot(model.extract(a, "something") == esoph$tobgp)

## Keywords: 'manip', 'programming', 'models'.


