###--- >>> `chartr' <<<----- Character Translation and Casefolding

	## alias	 help(chartr)
	## alias	 help(tolower)
	## alias	 help(toupper)
	## alias	 help(casefold)

##___ Examples ___:

x <- "MiXeD cAsE 123"
chartr("iXs", "why", x)
chartr("a-cX", "D-Fw", x)
tolower(x)
toupper(x)

## Keywords: 'character'.


