###--- >>> `fligner.test' <<<----- Fligner-Killeen Test for Homogeneity of Variances

	## alias	 help(fligner.test)
	## alias	 help(fligner.test.default)
	## alias	 help(fligner.test.formula)

##___ Examples ___:

data(InsectSprays)
plot(count ~ spray, data = InsectSprays)
fligner.test(InsectSprays$count, InsectSprays$spray)
fligner.test(count ~ spray, data = InsectSprays)
## Compare this to bartlett.test()

## Keywords: 'htest'.


