###--- >>> `Geometric' <<<----- The Geometric Distribution

	## alias	 help(dgeom)
	## alias	 help(pgeom)
	## alias	 help(qgeom)
	## alias	 help(rgeom)

##___ Examples ___:

pp <- sort(c((1:9)/10, 1 - .2^(2:8)))
print(qg <- qgeom(pp, prob = .2))
## test that qgeom is an inverse of pgeom
print(qg1 <- qgeom(pgeom(qg, prob=.2), prob =.2))
all(qg == qg1)
Ni <- rgeom(20, prob = 1/4); table(factor(Ni, 0:max(Ni)))

## Keywords: 'distribution'.


