###--- >>> `load' <<<----- Reload Saved Datasets

	## alias	 help(load)

##___ Examples ___:

## save all data
save(list = ls(), file= "all.Rdata")

## restore the saved values to the current environment
load("all.Rdata")

## restore the saved values to the workspace
load("all.Rdata", .GlobalEnv)

## Keywords: 'file'.


