###--- >>> `Machine' <<<----- Machine Characteristics

	## alias	 help(Machine)
	## alias	 help(.Machine)

##___ Examples ___:

str(Machine())
(Meps <- .Machine $ double.eps)

## All the following relations must hold :
stopifnot(
 1 +     Meps != 1,
 1 + .5* Meps == 1,
 log2(.Machine$double.xmax) == .Machine$double.max.exp,
 log2(.Machine$double.xmin) == .Machine$double.min.exp
)

## Keywords: 'sysdata', 'programming', 'math'.


