###--- >>> `expand.grid' <<<----- Create a Data Frame from All Combinations of Factors

	## alias	 help(expand.grid)

##___ Examples ___:

expand.grid(height = seq(60, 80, 5), weight = seq(100, 300, 50),
            sex = c("Male","Female"))

## Keywords: 'models'.


