###--- >>> `seq.POSIXt' <<<----- Generate Regular Sequences of Dates

	## alias	 help(seq.POSIXt)

##___ Examples ___:

## first days of years in the (commonly used) 20th century
seq(ISOdate(1910,1,1), ISOdate(1999,1,1), "years")
## by month
seq(ISOdate(2000,1,1), by="month", length=12)
## quarters
seq(ISOdate(1990,1,1), ISOdate(2000,1,1), by="3 months")

## Keywords: 'manip', 'chron'.


