###--- >>> `ppoints' <<<----- Ordinates for Probability Plotting

	## alias	 help(ppoints)

##___ Examples ___:

ppoints(4) # the same as  ppoints(1:4)
ppoints(10)
ppoints(10, a=1/2)

## Keywords: 'dplot', 'arith', 'distribution'.


