###--- >>> `c' <<<----- Combine Values into a Vector or List

	## alias	 help(c)

##___ Examples ___:

c(1,7:9)
c(1:5, 10.5, "next")

c(list(A=c(B=1)), recursive=TRUE)

c(options(), recursive=TRUE)
c(list(A=c(B=1,C=2), B=c(E=7)), recursive=TRUE)

## Keywords: 'manip'.


