###--- >>> `packageStatus' <<<----- Package Management Tools

	## alias	 help(compareVersion)
	## alias	 help(newestVersion)
	## alias	 help(packageStatus)
	## alias	 help(print.packageStatus)
	## alias	 help(summary.packageStatus)
	## alias	 help(update.packageStatus)
	## alias	 help(upgrade.packageStatus)
	## alias	 help(upgrade)

##___ Examples ___:

##Don't run: 
##D x <- packageStatus()
##D print(x)
##D summary(x)
##D upgrade(x)
##D x <- update(x)
##D print(x)

## Keywords: 'utilities'.


