###--- >>> `tabulate' <<<----- Tabulation for Vectors

	## alias	 help(tabulate)

##___ Examples ___:

tabulate(numeric(0))
tabulate(c(2,3,5))
tabulate(c(2,3,3,5), nb = 10)
tabulate(c(-2,0,2,3,3,5), nb = 3)
tabulate(factor(letters[1:10]))

## Keywords: 'arith'.


