###--- >>> `Control' <<<----- Control Flow

	## alias	 help(if)
	## alias	 help(else)
	## alias	 help(for)
	## alias	 help(while)
	## alias	 help(repeat)
	## alias	 help(break)
	## alias	 help(next)

##___ Examples ___:

for(i in 1:5) print(1:i)

## Keywords: 'programming', 'iteration', 'logic'.


