###--- >>> `read.fwf' <<<----- Read Fixed Width Format Files

	## alias	 help(read.fwf)

##___ Examples ___:

ff <- tempfile()
cat(file=ff, "123456", "987654", sep="\n")
read.fwf(ff, width=c(1,2,3))    #> 1 23 456 \ 9 87 654
unlink(ff)
cat(file=ff, "123", "987654", sep="\n")
read.fwf(ff, width=c(1,0, 2,3))    #> 1 NA 23 NA \ 9 NA 87 654
unlink(ff)

## Keywords: 'file', 'connection'.


