###--- >>> `morley' <<<----- Michaelson-Morley Speed of Light Data

	## alias	 help(morley)

##___ Examples ___:

data(morley)
morley$Expt <- factor(morley$Expt)
morley$Run <- factor(morley$Run)
attach(morley)
plot(Expt, Speed, main = "Speed of Light Data", xlab = "Experiment No.")
fm <- aov(Speed ~ Run + Expt, data = morley)
summary(fm)
fm0 <- update(fm, . ~ . - Run)
anova(fm0, fm)
detach(morley)

## Keywords: 'datasets'.


