###--- >>> `ifelse' <<<----- Conditional Element Selection

	## alias	 help(ifelse)

##___ Examples ___:

x <- c(6:-4)
sqrt(x)#- gives warning
sqrt(ifelse(x >= 0, x, NA))# no warning

## Note: the following also gives the warning !
ifelse(x >= 0, sqrt(x), NA)

## Keywords: 'logic', 'programming'.


