###--- >>> `uspop' <<<----- The Population of the United States

	## alias	 help(uspop)

##___ Examples ___:

data(uspop)
plot(uspop, log = "y", main = "uspop data", xlab = "Year",
     ylab = "U.S. Population (millions)")

## Keywords: 'datasets'.


