###--- >>> `chull' <<<----- Compute Convex Hull of a Set of Points

	## alias	 help(chull)

##___ Examples ___:

X <- matrix(rnorm(2000), ncol=2)
plot(X, cex=0.5)
hpts <- chull(X)
hpts <- c(hpts, hpts[1])
lines(X[hpts, ])

## Keywords: 'hplot'.


