###--- >>> `as.function' <<<----- Convert Object to Function

	## alias	 help(as.function)
	## alias	 help(as.function.default)

##___ Examples ___:

as.function(alist(a=,b=2,a+b))
as.function(alist(a=,b=2,a+b))(3)

## Keywords: 'programming'.


