###--- >>> `lm.fit' <<<----- Fitter Functions for Linear Models

	## alias	 help(lm.fit)
	## alias	 help(lm.wfit)
	## alias	 help(lm.fit.null)
	## alias	 help(lm.wfit.null)

##___ Examples ___:

set.seed(129)
n <- 7 ; p <- 2
X <- matrix(rnorm(n * p), n,p) # no intercept!
y <- rnorm(n)
w <- rnorm(n)^2

str(lmw <- lm.wfit(x=X, y=y, w=w))

str(lm. <- lm.fit (x=X, y=y))

str(lm0 <-  lm.fit.null (x=X, y=y))
str(lmw0 <- lm.wfit.null(x=X, y=y,w=w))


## Keywords: 'regression', 'array'.


