###--- >>> `file.info' <<<----- Extract File Information

	## alias	 help(file.info)

##___ Examples ___:

ncol(finf <- file.info(dir()))# at least six
##Don't run: finf # the whole list
## Those that are more than 100 days old :
finf[difftime(Sys.time(), finf[,"mtime"], units="days") > 100 , 1:4]

file.info("no-such-file-exists")

## Keywords: 'file'.


