###--- >>> `contrast' <<<----- Contrast Matrices

	## alias	 help(contr.helmert)
	## alias	 help(contr.poly)
	## alias	 help(contr.sum)
	## alias	 help(contr.treatment)

##___ Examples ___:

(cH <- contr.helmert(4))
apply(cH, 2,sum) # column sums are 0!
crossprod(cH) # diagonal -- columns are orthogonal
contr.helmert(4, contrasts = FALSE) # just the 4 x 4 identity matrix

(cT <- contr.treatment(5))
all(crossprod(cT) == diag(4)) # TRUE: even orthonormal

(cP <- contr.poly(3)) # Linear and Quadratic
zapsmall(crossprod(cP), dig=15) # orthonormal up to fuzz

## Keywords: 'design', 'regression', 'array'.


