###--- >>> `pressure' <<<----- Vapor Pressure of Mercury as a Function of Temperature

	## alias	 help(pressure)

##___ Examples ___:

data(pressure)
plot(pressure, xlab = "Temperature (deg C)",
     ylab = "Pressure (mm of Hg)",
     main = "pressure data: Vapor Pressure of Mercury")
plot(pressure, xlab = "Temperature (deg C)",  log = "y",
     ylab = "Pressure (mm of Hg)",
     main = "pressure data: Vapor Pressure of Mercury")

## Keywords: 'datasets'.


