###--- >>> `getNumCConverters' <<<----- Management of .C argument conversion list

	## alias	 help(getNumCConverters)
	## alias	 help(getCConverterDescriptions)
	## alias	 help(getCConverterStatus)
	## alias	 help(setCConverterStatus)
	## alias	 help(removeCConverter)

##___ Examples ___:

 getNumCConverters()
 getCConverterDescriptions()
 getCConverterStatus()
##Don't run: 
##D   old <- setCConverterStatus(1,FALSE)
##D 
##D   setCConverterStatus(1,old)

##Don't run: 
##D   removeCConverter(1)
##D   removeCConverter(getCConverterDescriptions()[1])


## Keywords: 'interface', 'programming'.


