###--- >>> `unname' <<<----- Remove `names' or `dimnames'

	## alias	 help(unname)

##___ Examples ___:

## Answering a question on R-help (14 Oct 1999):
col3 <- 750+ 100* rt(1500, df = 3)
breaks <- factor(cut(col3,breaks=360+5*(0:155)))
str(table(breaks)) # The names are quite larger than the data ...
barplot(unname(table(breaks)), axes= FALSE)

## Keywords: 'utilities'.


