###--- >>> `round.POSIXt' <<<----- Round / Truncate Data-Time Objects

	## alias	 help(round.POSIXt)
	## alias	 help(trunc.POSIXt)

##___ Examples ___:

round(.leap.seconds + 1000, "hour")
trunc.POSIXt(Sys.time(), "day")

## Keywords: 'chron'.


