###--- >>> `print.matrix' <<<----- Print Matrices

	## alias	 help(print.matrix)
	## alias	 help(prmatrix)

##___ Examples ___:

print.matrix(m6 <- diag(6), row = rep("",6), coll=rep("",6))

chm <- matrix(scan(system.file("help", "AnIndex", package = "eda"),
                   what = ""), , 2, byrow = TRUE)
chm  #-> print.default(.)  = `same' as  print.matrix(chm)
print.matrix(chm, collab = paste("Column",1:3), right=TRUE, quote=FALSE)

## Keywords: 'print'.


