###--- >>> `all.names' <<<----- Find All Names in an Expression

	## alias	 help(all.names)
	## alias	 help(all.vars)

##___ Examples ___:

all.names(expression(sin(x+y)))
all.vars(expression(sin(x+y)))

## Keywords: 'programming'.


