###--- >>> `remove' <<<----- Remove Objects from a Specified Environment

	## alias	 help(rm)
	## alias	 help(remove)

##___ Examples ___:

tmp <- 1:4
## work with tmp  and cleanup
rm(tmp)

##Don't run: 
##D ## remove (almost) everything in the working environment.
##D ## You will get no warning, so don't do this unless you are really sure.
##D rm(list = ls())

## Keywords: 'environment'.


