###--- >>> `is.language' <<<----- Is an Object a Language Object?

	## alias	 help(is.language)

##___ Examples ___:

ll <- list(a = expression(x^2 - 2*x + 1), b = as.name("Jim"),
           c = as.expression(exp(1)), d = call("sin", pi))
sapply(ll, typeof)
sapply(ll, mode)
stopifnot(sapply(ll, is.language))

## Keywords: 'programming'.


