###--- >>> `body' <<<----- Access to and Manipulation of the Body of a Function

	## alias	 help(body)
	## alias	 help(body<-)

##___ Examples ___:

body(body)
f <- function(x) x^5
body(f) <- expression(5^x)
f(3) # = 125
str(body(f))

## Keywords: 'programming'.


