###--- >>> `co2' <<<----- Mauna Loa Atmospheric CO2 Concentration

	## alias	 help(co2)

##___ Examples ___:

data(co2)
plot(co2, ylab = expression("Atmospheric concentration of CO"[2]),
     las = 1)
title(main = "co2 data set")

## Keywords: 'datasets'.


