###--- >>> `pairwise.prop.test' <<<----- Pairwise comparisons of proportions

	## alias	 help(pairwise.prop.test)

##___ Examples ___:

smokers  <- c( 83, 90, 129, 70 )
patients <- c( 86, 93, 136, 82 )
pairwise.prop.test(smokers, patients)

## Keywords: 'htest'.


