###--- >>> `row' <<<----- Row Indexes

	## alias	 help(row)

##___ Examples ___:

x <- matrix(1:12, 3, 4)
# extract the diagonal of a matrix
dx <- x[row(x) == col(x)]
dx

# create an identity 5-by-5 matrix
x <- matrix(0, nr = 5, nc = 5)
x[row(x) == col(x)] <- 1
x

## Keywords: 'array'.


