###--- >>> `coefficients' <<<----- Extract Model Coefficients

	## alias	 help(coef)
	## alias	 help(coefficients)
	## alias	 help(coef.default)
	## alias	 help(coef.lm)
	## alias	 help(coef.glm)
	## alias	 help(coef.aov)
	## alias	 help(coef.listof)

##___ Examples ___:

x <- 1:5; coef(lm(c(1:3,7,6) ~ x))

## Keywords: 'regression', 'models'.


