###--- >>> `charmatch' <<<----- Partial String Matching

	## alias	 help(charmatch)

##___ Examples ___:

charmatch("", "")                             # returns 1
charmatch("m",   c("mean", "median", "mode")) # returns 0
charmatch("med", c("mean", "median", "mode")) # returns 2

## Keywords: 'character'.


