###--- >>> `sort' <<<----- Sorting a Vector

	## alias	 help(sort)
	## alias	 help(is.unsorted)

##___ Examples ___:

data(swiss)
x <- swiss$Education[1:25]
x; sort(x); sort(x, partial = c(10, 15))
median # shows you another example for `partial'

stopifnot(!is.unsorted(sort(x)),
          !is.unsorted(LETTERS),
           is.unsorted(c(NA,1:3,2), na.rm = TRUE))

## Keywords: 'univar', 'manip', 'arith'.


