###--- >>> `Exponential' <<<----- The Exponential Distribution

	## alias	 help(dexp)
	## alias	 help(pexp)
	## alias	 help(qexp)
	## alias	 help(rexp)

##___ Examples ___:

dexp(1) - exp(-1) #-> 0
r <- rexp(100)
all(abs(1 - dexp(1, r) / (r*exp(-r))) < 1e-14)

## Keywords: 'distribution'.


