###--- >>> `lm.summary' <<<----- Summarizing Linear Model Fits

	## alias	 help(summary.lm)
	## alias	 help(summary.lm.null)
	## alias	 help(summary.mlm)
	## alias	 help(print.summary.lm)
	## alias	 help(print.summary.lm.null)

##___ Examples ___:

example("lm", echo = FALSE)
##-- Continuing the  lm(.) example:
coef(lm.D90)# the bare coefficients
sld90 <- summary(lm.D90 <- lm(weight ~ group -1))# omitting intercept
sld90
coef(sld90)# much more

## Keywords: 'regression', 'models'.


