###--- >>> `anova.glm' <<<----- Analysis of Deviance for Generalized Linear Model Fits

	## alias	 help(anova.glm)
	## alias	 help(anova.glmlist)
	## alias	 help(anova.glm.null)

##___ Examples ___:

## --- Continuing the Example from  ``?glm'':
example("glm", echo = FALSE)
anova(glm.D93)
anova(glm.D93, test = "Cp")
anova(glm.D93, test = "Chisq")

## Keywords: 'models', 'regression'.


