###--- >>> `paste' <<<----- Concatenate Strings

	## alias	 help(paste)

##___ Examples ___:

paste(1:12) # same as as.character(1:12)
paste("A", 1:6, sep = "")
paste("Today is", date())

## Keywords: 'character'.


