###--- >>> `environment' <<<----- Environment Access

	## alias	 help(environment)
	## alias	 help(environment<-)
	## alias	 help(.GlobalEnv)
	## alias	 help(globalenv)
	## alias	 help(is.environment)
	## alias	 help(new.env)
	## alias	 help(parent.env)
	## alias	 help(parent.env<-)
	## alias	 help(.BaseNamespaceEnv)

##___ Examples ___:

##-- all three give the same:
environment()
environment(environment)
.GlobalEnv

ls(envir=environment(approxfun(1:2,1:2, method="const")))

is.environment(.GlobalEnv)# TRUE

e1 <- new.env(TRUE, NULL)
e2 <- new.env(FALSE, NULL)
assign("a", 3, env=e2)
parent.env(e1) <- e2
get("a", env=e1)


## Keywords: 'data', 'programming'.


