###--- >>> `is.object' <<<----- Is an Object ``internally classed''?

	## alias	 help(is.object)

##___ Examples ___:

is.object(1) # FALSE
is.object(as.factor(1:3)) # TRUE

## Keywords: 'methods', 'classes'.


