###--- >>> `lines' <<<----- Add Connected Line Segments to a Plot

	## alias	 help(lines)
	## alias	 help(lines.default)

##___ Examples ___:

data(cars)
# draw a smooth line through a scatter plot
plot(cars, main="Stopping Distance versus Speed")
lines(lowess(cars))

## Keywords: 'aplot'.


