###--- >>> `AIC' <<<----- Akaike Information Criterion

	## alias	 help(AIC)
	## alias	 help(AIC.default)
	## alias	 help(AIC.lm)

##___ Examples ___:

data(swiss)
lm1 <- lm(Fertility ~ . , data = swiss)
AIC(lm1)
stopifnot(all.equal(AIC(lm1),
                    AIC(logLik(lm1))))
## a version of BIC or Schwarz' BC :
AIC(lm1, k = log(nrow(swiss)))

## Keywords: 'models'.


