###--- >>> `panel.smooth' <<<----- Simple Panel Plot

	## alias	 help(panel.smooth)

##___ Examples ___:

data(swiss)
pairs(swiss, panel = panel.smooth, pch = ".")# emphasize the smooths
pairs(swiss, panel = panel.smooth, lwd = 2, cex= 1.5, col="blue")# hmm...

## Keywords: 'hplot', 'dplot'.


