###--- >>> `any' <<<----- Are Some Values True?

	## alias	 help(any)

##___ Examples ___:

range(x <- sort(round(rnorm(10) - 1.2,1)))
if(any(x < 0)) cat("x contains negative values\n")

## Keywords: 'logic'.


