###--- >>> `nls.control' <<<----- Control the Iterations in nls

	## alias	 help(nls.control)

##___ Examples ___:

nls.control(minFactor = 1/2048)

## Keywords: 'nonlinear', 'regression', 'models'.


