###--- >>> `OrchardSprays' <<<----- Potency of Orchard Sprays

	## alias	 help(OrchardSprays)

##___ Examples ___:

data(OrchardSprays)
pairs(OrchardSprays, main = "OrchardSprays data")

## Keywords: 'datasets'.


