###--- >>> `summary.princomp' <<<----- Summary method for Principal Components Analysis

	## alias	 help(summary.princomp)

##___ Examples ___:

data(USArrests)
summary(pc.cr <- princomp(USArrests, cor=TRUE))
summary(princomp(USArrests, cor=TRUE),
        loadings = TRUE, cutoff = 0.2, digits = 2)

## Keywords: 'multivariate'.


