###--- >>> `substr' <<<----- Substrings of a Character Vector

	## alias	 help(substr)
	## alias	 help(substring)
	## alias	 help(substr<-)
	## alias	 help(substring<-)

##___ Examples ___:

substr("abcdef",2,4)
print(ss <- substring("abcdef",1:6,1:6))
stopifnot(ss == strsplit ("abcdef",NULL)[[1]])
## strsplit is more efficient ...

substr(rep("abcdef",4),1:4,4:5)
x <- c("asfef", "qwerty", "yuiop[", "b", "stuff.blah.yech")
stopifnot(substr(x, 2, 5) == substring(x, 2, 5))
substr(x, 2, 5)
substring(x, 2, 4:6)

substring(x, 2) <- c("..", "+++")
x

## Keywords: 'character'.


