###--- >>> `det' <<<----- Calculate the Determinant of a Matrix

	## alias	 help(det)

##___ Examples ___:

(x <- matrix(1:4, ncol=2))
det(x)
det(x, method="eigenvalues")

det(print(cbind(1,1:3,c(2,0,1))))

## Keywords: 'array'.


