###--- >>> `check.options' <<<----- Set Options with Consistency Checks

	## alias	 help(check.options)

##___ Examples ___:

L1 <- list(a=1:3, b=pi, ch="CH")
str(L2 <- check.options(list(a=0:2), name.opt = "L1"))
str(check.options(NULL, reset = TRUE, name.opt = "L1"))

## Keywords: 'utilities', 'programming'.


