###--- >>> `ksmooth' <<<----- Kernel Regression Smoother

	## alias	 help(ksmooth)

##___ Examples ___:

data(cars)
attach(cars)
plot(speed, dist)
lines(ksmooth(speed, dist, "normal", bandwidth=2), col=2)
lines(ksmooth(speed, dist, "normal", bandwidth=5), col=3)
lines(ksmooth(speed, dist, "normal", bandwidth=10), col=4)
detach()

## Keywords: 'smooth'.


