###--- >>> `nhtemp' <<<----- Average Yearly Temperatures in New Haven

	## alias	 help(nhtemp)

##___ Examples ___:

data(nhtemp)
plot(nhtemp, main = "nhtemp data",
  ylab = "Mean annual temperature in New Haven, CT (deg. F)")

## Keywords: 'datasets'.


