###--- >>> `attenu' <<<----- The Joyner-Boore Attenuation Data

	## alias	 help(attenu)

##___ Examples ___:

data(attenu)
## check the data class of the variables
sapply(attenu, data.class)
summary(attenu)
pairs(attenu, main = "attenu data")
coplot(accel ~ dist | as.factor(event), data = attenu, show = FALSE)
coplot(log(accel) ~ log(dist) | as.factor(event),
       data = attenu, panel = panel.smooth, show.given = FALSE)

## Keywords: 'datasets'.


