###--- >>> `stack' <<<----- Stack or Unstack Vectors from a Data Frame or List

	## alias	 help(stack)
	## alias	 help(stack.default)
	## alias	 help(stack.data.frame)
	## alias	 help(unstack)
	## alias	 help(unstack.default)
	## alias	 help(unstack.data.frame)

##___ Examples ___:

data(PlantGrowth)
formula(PlantGrowth)         # check the default formula
pg <- unstack(PlantGrowth)   # unstack according to this formula
pg
stack(pg)                    # now put it back together
stack(pg, select = -ctrl)    # omitting one vector

## Keywords: 'manip'.


