###--- >>> `write.table' <<<----- Data Output

	## alias	 help(write.table)

##___ Examples ___:

##Don't run: 
##D ## To write a CSV file for input to Excel one might use
##D write.table(x, file = "foo.csv", sep = ",", col.names = NA)
##D ## and to read this file back into R one needs
##D read.table("file.csv", header = TRUE, sep = ",", row.names=1)

## Keywords: 'print', 'file'.


