###--- >>> `Chisquare' <<<----- The (non-central) Chi-Squared Distribution

	## alias	 help(Chisquare)
	## alias	 help(dchisq)
	## alias	 help(pchisq)
	## alias	 help(qchisq)
	## alias	 help(rchisq)

##___ Examples ___:

dchisq(1, df=1:3)
pchisq(1, df= 3)
pchisq(1, df= 3, ncp = 0:4)# includes the above

x <- 1:10
## Chi-squared(df = 2) is a special exponential distribution
all.equal(dchisq(x, df=2), dexp(x, 1/2))
all.equal(pchisq(x, df=2), pexp(x, 1/2))

## Keywords: 'distribution'.


