###--- >>> `getMethod' <<<----- Get the Definition of a Method

	## alias	 help(getMethod)
	## alias	 help(findMethod)
	## alias	 help(getMethods)
	## alias	 help(selectMethod)
	## alias	 help(MethodsListSelect)

##___ Examples ___:



## Keywords: 'programming', 'classes', 'methods'.


