###--- >>> `.Script' <<<----- Scripting Language Interface

	## alias	 help(.Script)

##___ Examples ___:

.Script("perl", "maketitle.pl", file.path(.Library, "base", "TITLE"))

## Keywords: 'interface'.


