###--- >>> `profile.nls' <<<----- Method for Profiling nls Objects

	## alias	 help(profile.nls)

##___ Examples ___:

data( BOD )
# obtain the fitted object
fm1 <- nls(demand ~ SSasympOrig( Time, A, lrc ), data = BOD)
# get the profile for the fitted model
pr1 <- profile( fm1 )
# profiled values for the two parameters
pr1$A
pr1$lrc

## Keywords: 'nonlinear', 'regression', 'models'.


