###--- >>> `interactive' <<<----- Is R Running Interactively?

	## alias	 help(interactive)

##___ Examples ___:

 .First <- function() if(interactive()) x11()

## Keywords: 'environment', 'programming'.


