###--- >>> `cbind' <<<----- Combine R Objects by Rows or Columns

	## alias	 help(cbind)
	## alias	 help(rbind)
	## alias	 help(cbind.data.frame)
	## alias	 help(rbind.data.frame)

##___ Examples ___:

cbind(1, 1:7) # the `1' (= shorter vector) is recycled
cbind(1:7, diag(3))# vector is subset -> warning

cbind(0, rbind(1, 1:3))

cbind(0, matrix(1, nrow=0, ncol=4))#> Warning (making sense)
dim(cbind(0, matrix(1, nrow=2, ncol=0)))#-> 2 x 1

## Keywords: 'array', 'manip'.


