###--- >>> `data.frame' <<<----- Data Frames

	## alias	 help(data.frame)
	## alias	 help(as.data.frame)
	## alias	 help(is.data.frame)
	## alias	 help(row.names)
	## alias	 help(row.names.data.frame)
	## alias	 help(row.names.default)
	## alias	 help(row.names<-)
	## alias	 help(row.names<-.data.frame)
	## alias	 help(row.names<-.default)
	## alias	 help(plot.data.frame)
	## alias	 help([.AsIs)
	## alias	 help(as.data.frame.AsIs)
	## alias	 help(as.data.frame.character)
	## alias	 help(as.data.frame.complex)
	## alias	 help(as.data.frame.data.frame)
	## alias	 help(as.data.frame.default)
	## alias	 help(as.data.frame.factor)
	## alias	 help(as.data.frame.integer)
	## alias	 help(as.data.frame.list)
	## alias	 help(as.data.frame.logical)
	## alias	 help(as.data.frame.matrix)
	## alias	 help(as.data.frame.model.matrix)
	## alias	 help(as.data.frame.numeric)
	## alias	 help(as.data.frame.ordered)
	## alias	 help(as.data.frame.ts)
	## alias	 help(as.data.frame.vector)
	## alias	 help(xpdrows.data.frame)

##___ Examples ___:

L3 <- LETTERS[1:3]
str(d <- data.frame(cbind(x=1, y=1:10), fac=sample(L3, 10, repl=TRUE)))

## The same with automatic column names:
str(     data.frame(cbind(  1,   1:10),     sample(L3, 10, repl=TRUE)))
is.data.frame(d)

## do not convert to factor, using I() :
str(cbind(d, char = I(letters[1:10])), vec.len = 10)

stopifnot(1:10 == row.names(d))# {coercion}

(d0  <- d[, FALSE]) # NULL dataframe with 10 rows
(d.0 <- d[FALSE, ]) # <0 rows> dataframe  (3 cols)
(d00 <- d0[FALSE,])  # NULL dataframe with 0 rows

(d000 <- data.frame()) #but not quite the same as d00:
!identical(d00, d000)
dput(d00)
dput(d000)
stopifnot(identical(d, cbind(d, d0)),
          identical(d, cbind(d0, d)),
          identical(d, rbind(d,d.0)),
          identical(d, rbind(d.0,d)),
          identical(d, rbind(d00,d)),
          identical(d, rbind(d,d00)),

          TRUE )
## These are not true: dim is ok, but names() not {seen via dput}
##          identical(d0, rbind(d0,d00)),
#         identical(d0, rbind(d00,d0)),
#          identical(d00,rbind(d00,d00)),
#          identical(d00,cbind(d00,d00)),



## Keywords: 'classes', 'methods'.


