###--- >>> `codes' <<<----- Factor Codes

	## alias	 help(codes)
	## alias	 help(codes.factor)
	## alias	 help(codes.ordered)
	## alias	 help(codes<-)

##___ Examples ___:

codes(rep(factor(c(20,10)),3))

x <- gl(3,5)
codes(x)[3] <- 2
x

data(esoph)
( ag <- esoph$alcgp[12:1] )
codes(ag)

codes(factor(1:10)) # BEWARE!

## Keywords: 'category', 'classes'.


