###--- >>> `invisible' <<<----- Change the Print Mode to Invisible

	## alias	 help(invisible)

##___ Examples ___:

# These functions both return their argument
f1 <- function(x) x
f2 <- function(x) invisible(x)
f1(1)# prints
f2(1)# does not

## Keywords: 'programming'.


