###--- >>> `dcf' <<<----- Read and Write Data in DCF Format

	## alias	 help(read.dcf)
	## alias	 help(write.dcf)

##___ Examples ___:

## Create a reduced version of the `CONTENTS' file in package `eda'
x <- read.dcf(file = system.file("CONTENTS", package = "eda"),
               fields = c("Entry", "Description"))
write.dcf(x)

## Keywords: 'print', 'file'.


