###--- >>> `abs' <<<----- Miscellaneous Mathematical Functions

	## alias	 help(abs)
	## alias	 help(sqrt)

##___ Examples ___:

xx <- -9:9
plot(xx, sqrt(abs(xx)),  col = "red")
lines(spline(xx, sqrt(abs(xx)), n=101), col = "pink")

## Keywords: 'math'.


