###--- >>> `sink' <<<----- Send R Output to a File

	## alias	 help(sink)
	## alias	 help(sink.number)

##___ Examples ___:

sink("sink-examp.txt")
i <- 1:10
outer(i, i, "*")
sink()
unlink("sink-examp.txt")
##Don't run: 
##D ## capture all the output to a file.
##D zz <- file("all.Rout", open="wt")
##D sink(zz)
##D sink(zz, type="message")
##D try(log("a"))
##D ## back to the console
##D sink(type="message")
##D sink()
##D try(log("a"))

## Keywords: 'file', 'connection'.


