###--- >>> `Hypergeometric' <<<----- The Hypergeometric Distribution

	## alias	 help(dhyper)
	## alias	 help(phyper)
	## alias	 help(qhyper)
	## alias	 help(rhyper)

##___ Examples ___:

m <- 10; n <- 7; k <- 8
x <- 0:(k+1)
rbind(phyper(x, m, n, k), dhyper(x, m, n, k))
all(phyper(x, m, n, k) == cumsum(dhyper(x, m, n, k)))# FALSE
## but error is very small:
signif(phyper(x, m, n, k) - cumsum(dhyper(x, m, n, k)), dig=3)

## Keywords: 'distribution'.


