###--- >>> `trace' <<<----- Trace All Calls to a Function.

	## alias	 help(trace)
	## alias	 help(untrace)

##___ Examples ___:

trace(names)
data.frame(x=1:2, y=3:4)
untrace(names)

## Keywords: 'programming'.


