###--- >>> `plot.window' <<<----- Set up World Coordinates for Graphics Window

	## alias	 help(plot.window)

##___ Examples ___:

##--- An example for the use of  `asp' :
library(mva)
data(eurodist)
loc <- cmdscale(eurodist)
rx <- range(x <- loc[,1])
ry <- range(y <- -loc[,2])
plot(x, y, type="n", asp=1, xlab="", ylab="")
abline(h=pretty(rx, 10),
       v=pretty(ry, 10), col= "lightgray")
text(x, y, names(eurodist), cex=0.5)
detach("package:mva")

## Keywords: 'aplot'.


