###--- >>> `ansari.test' <<<----- Ansari-Bradley Test

	## alias	 help(ansari.test)
	## alias	 help(ansari.test.default)
	## alias	 help(ansari.test.formula)

##___ Examples ___:

## Hollander & Wolfe (1973, p. 86f):
## Serum iron determination using Hyland control sera
ramsay <- c(111, 107, 100, 99, 102, 106, 109, 108, 104, 99,
            101, 96, 97, 102, 107, 113, 116, 113, 110, 98)
jung.parekh <- c(107, 108, 106, 98, 105, 103, 110, 105, 104,
            100, 96, 108, 103, 104, 114, 114, 113, 108, 106, 99)
ansari.test(ramsay, jung.parekh)

ansari.test(rnorm(10), rnorm(10, 0, 2), conf.int = TRUE)

## Keywords: 'htest'.


