###--- >>> `screeplot' <<<----- Screeplot of PCA Results

	## alias	 help(screeplot)

##___ Examples ___:

## The variances of the variables in the
## USArrests data vary by orders of magnitude, so scaling is appropriate
data(USArrests)
(pc.cr <- princomp(USArrests, cor = TRUE))  # inappropriate
screeplot(pc.cr)

data(Harman74.cor)
fit <- princomp(covmat=Harman74.cor)
screeplot(fit)
screeplot(fit, npcs=24, type="lines")

## Keywords: 'multivariate'.


