###--- >>> `polySpline' <<<----- Piecewise Polynomial Spline Representation

	## alias	 help(polySpline)
	## alias	 help(polySpline.bSpline)
	## alias	 help(polySpline.nbSpline)
	## alias	 help(polySpline.pbSpline)
	## alias	 help(polySpline.polySpline)
	## alias	 help(as.polySpline)
	## alias	 help(predict.polySpline)
	## alias	 help(print.polySpline)

##___ Examples ___:

data( women )
ispl <- polySpline( interpSpline( weight ~ height,  women, bSpline = TRUE ) )
print( ispl )   # print the piecewise polynomial representation
plot( ispl )    # plots over the range of the knots
points( women$height, women$weight )

## Keywords: 'models'.


