###--- >>> `commandArgs' <<<----- Extract Command Line Arguments

	## alias	 help(commandArgs)

##___ Examples ___:

commandArgs()
## Spawn a copy of this  application as it was invoked.
## system(paste(commandArgs(), collapse=" "))

## Keywords: 'environment', 'sysdata', 'programming'.


