###--- >>> `representation' <<<----- Describe A Class Representation

	## alias	 help(representation)

##___ Examples ___:

## representation for a new class with a directly define slot "smooth"
## which should be a "numeric" object, and extending class "track"
representation("track", smooth ="numeric")

setClass("class1", representation(a="numeric", b = "character"))
setClass("class2", representation(a2 = "numeric", b = "numeric"))
try(setClass("class3", representation("class1", "class2")))



## Keywords: 'programming', 'classes'.


