###--- >>> `swiss' <<<----- Swiss Fertility and Socioeconomic Indicators (1888) Data

	## alias	 help(swiss)

##___ Examples ___:

data(swiss)
pairs(swiss, panel = panel.smooth, main = "swiss data",
      col = 3 + (swiss$Catholic > 50))
summary(lm(Fertility ~ . , data = swiss))

## Keywords: 'datasets'.


