###--- >>> `capabilities' <<<----- Report Capabilities of this Build of R

	## alias	 help(capabilities)

##___ Examples ___:

capabilities()

if(!capabilities("http/ftp"))
   warning("internal download.file() is not available")

## See also the examples for `connections'.

## Keywords: 'utilities'.


