###--- >>> `weighted.residuals' <<<----- Compute Weighted Residuals

	## alias	 help(weighted.residuals)

##___ Examples ___:

example("lm")
all.equal(weighted.residuals(lm.D9),
          residuals(lm.D9))
x <- 1:10
w <- 0:9
y <- rnorm(x)
weighted.residuals(lmxy <- lm(y ~ x, weights = w))
weighted.residuals(lmxy, drop0 = FALSE)

## Keywords: 'regression'.


