###--- >>> `Methods' <<<----- Internal and Group Methods and Generic Functions

	## alias	 help(Methods)
	## alias	 help(.Method)
	## alias	 help(.Generic)
	## alias	 help(.Group)
	## alias	 help(.Class)
	## alias	 help(Math)
	## alias	 help(Math.data.frame)
	## alias	 help(Math.factor)
	## alias	 help(Ops)
	## alias	 help(Ops.data.frame)
	## alias	 help(Ops.factor)
	## alias	 help(Ops.ordered)
	## alias	 help(Summary)
	## alias	 help(Summary.data.frame)
	## alias	 help(Summary.factor)

##___ Examples ___:

methods("Math")
methods("Ops")
methods("Summary")

d.fr <- data.frame(x=1:9, y=rnorm(9))
data.class(1 + d.fr) == "data.frame" ##-- add to d.f. ...

## Keywords: 'methods'.


