###--- >>> `Primitive' <<<----- Call a ``Primitive'' Internal Function

	## alias	 help(.Primitive)

##___ Examples ___:

mysqrt <- .Primitive("sqrt")
c
.Internal # this one *must* be primitive!
get("if") # just `if' or `print(if)' are not syntactically ok.

## Keywords: 'interface'.


