###--- >>> `lsfit' <<<----- Find the Least Squares Fit

	## alias	 help(lsfit)

##___ Examples ___:

example("lm", echo = FALSE)
##-- Using the same data as the lm(.) example:
lsD9 <- lsfit(x = codes(gl(2,10)), y = weight)
ls.print(lsD9)

## Keywords: 'regression'.


