###--- >>> `sortedXyData' <<<----- Create a sortedXyData object

	## alias	 help(sortedXyData)
	## alias	 help(sortedXyData.default)

##___ Examples ___:

data( DNase )
DNase.2 <- DNase[ DNase$Run == "2", ]
sortedXyData( expression(log(conc)), expression(density), DNase.2 )

## Keywords: 'manip'.


