###--- >>> `TclInterface' <<<----- Low-level Tcl/Tk Interface

	## alias	 help(TclInterface)
	## alias	 help(.Tcl)
	## alias	 help(.Tcl.callback)
	## alias	 help(.Tcl.args)
	## alias	 help($.tclvar)
	## alias	 help($<-.tclvar)
	## alias	 help(tclvar)
	## alias	 help(tclVar)
	## alias	 help(as.character.tclVar)
	## alias	 help(tclvalue)
	## alias	 help(tclvalue<-)
	## alias	 help(tclvalue.default)
	## alias	 help(tclvalue<-.default)
	## alias	 help(tclvalue.tclVar)
	## alias	 help(tclvalue<-.tclVar)
	## alias	 help(.Tk.ID)
	## alias	 help(.Tk.newwin)
	## alias	 help(.Tk.subwin)
	## alias	 help(is.tkwin)
	## alias	 help(tkdestroy)
	## alias	 help(.TkWin)
	## alias	 help(.TkRoot)
	## alias	 help(addTclPath)
	## alias	 help(tclRequire)

##___ Examples ___:

##Don't run: 
##D ## These cannot be run by example() but should be OK when pasted
##D ## into an interactive R session with the tcltk package loaded
##D .Tcl("format \"%s\n\" \"Hello, World!\"")
##D f <- function()"HI!"
##D .Tcl.callback(f)
##D .Tcl.args(text="Push!", command=f) # NB: Different address
##D 
##D xyzzy <- tclVar(7913)
##D tclvalue(xyzzy)
##D tclvalue(xyzzy) <- "foo"
##D as.character(xyzzy)
##D tkcmd("set", as.character(xyzzy))
##D 
##D top <- tktoplevel() # a Tk widget, see Tk-widgets
##D ls(envir=top$env, all=TRUE)
##D ls(envir=.TkRoot$env, all=TRUE)# .Tcl.args put a callback ref in here


## Keywords: 'misc'.


