###--- >>> `save' <<<----- Save R Objects

	## alias	 help(save)
	## alias	 help(save.image)
	## alias	 help(sys.save.image)
	## alias	 help(sys.load.image)

##___ Examples ___:

x <- runif(20)
y <- list(a = 1, b = TRUE, c = "oops")
save(x, y, file = "xy.Rdata")
save.image()
unlink("xy.Rdata")
unlink(".RData")

# set save.image dafaults using option:
options(save.image.defaults=list(ascii=TRUE, safe=FALSE))
save.image()
unlink(".RData")

## Keywords: 'file'.


