###--- >>> `machine' <<<----- Determine the Machine R is Running On

	## alias	 help(machine)

##___ Examples ___:

machine()# to see yours
tolower(machine()) == .Platform $ OS ## --> often TRUE
if (machine() == "Macintosh")
  cat("You are using a Macintosh computer\n")

## Keywords: 'environment', 'programming'.


