###--- >>> `dotchart' <<<----- Cleveland Dot Plots

	## alias	 help(dotchart)

##___ Examples ___:

data(VADeaths)
dotchart(VADeaths, main = "Death Rates in Virginia - 1940")
dotchart(t(VADeaths), main = "Death Rates in Virginia - 1940")

## Keywords: 'hplot'.


