###--- >>> `pairs.formula' <<<----- Formula Notation for Scatterplot Matrices

	## alias	 help(pairs.formula)

##___ Examples ___:

data(swiss)
pairs(~ Fertility + Education + Catholic, data = swiss,
      subset = Education < 20, main = "Swiss data, Education < 20")

## Keywords: 'hplot'.


