###--- >>> `optimize' <<<----- One Dimensional Optimization

	## alias	 help(optimize)
	## alias	 help(optimise)

##___ Examples ___:

f <- function (x,a) (x-a)^2
xmin <- optimize(f, c(0, 1), tol = 0.0001, a = 1/3)
xmin

## Keywords: 'optimize'.


