###--- >>> `relevel' <<<----- Reorder Levels of Factor

	## alias	 help(relevel)
	## alias	 help(relevel.default)
	## alias	 help(relevel.factor)
	## alias	 help(relevel.ordered)

##___ Examples ___:

data(warpbreaks)
warpbreaks$tension <- relevel(warpbreaks$tension, ref="M")
summary(lm(breaks ~ wool + tension, data=warpbreaks))

## Keywords: 'utilities', 'models'.


