###--- >>> `delay' <<<----- Delay Evaluation

	## alias	 help(delay)

##___ Examples ___:

x <- delay({
    for(i in 1:7)
        cat("yippee!\n")
    10
})

x^2#- yippee
x^2#- simple number

## Keywords: 'programming', 'data'.


