###--- >>> `rev' <<<----- Reverse a Vector's Elements

	## alias	 help(rev)

##___ Examples ___:

x <- c(1:5,5:3)
# sort into descending order
rev(sort(x))
stopifnot(rev(1:7) == 7:1)#- don't need `rev' here

## Keywords: 'manip'.


