###--- >>> `Indometh' <<<----- Pharmacokinetics of Indomethicin

	## alias	 help(Indometh)

##___ Examples ___:

data(Indometh)
fm1 <- nls(conc ~ SSbiexp(time, A1, lrc1, A2, lrc2),
           data = Indometh, subset = Subject == 1)
summary(fm1)

## Keywords: 'datasets'.


