###--- >>> `mean' <<<----- Arithmetic Mean

	## alias	 help(mean)
	## alias	 help(mean.default)
	## alias	 help(mean.data.frame)

##___ Examples ___:

x <- c(0:10, 50)
xm <- mean(x)
c(xm, mean(x, trim = 0.10))

all.equal(mean(x, trim = 0.5), median(x))

data(USArrests)
mean(USArrests, trim = 0.2)

## Keywords: 'univar'.


