###--- >>> `taskCallbackManager' <<<----- Create an R-level task callback manager

	## alias	 help(taskCallbackManager)

##___ Examples ___:

   # create the manager
  h <- taskCallbackManager()

   # add a callback
  h$add(function(expr, value, ok, visible) {
                         cat("In handler\n")
                         return(TRUE)
                       }, name = "simpleHandler")

   # look at the internal callbacks.
  getTaskCallbackNames()

   # look at the R-level callbacks
  names(h$callback())
 
   #
  getTaskCallbackNames()
  removeTaskCallback("R-taskCallbackManager")

## Keywords: 'environment'.


