###--- >>> `getNativeSymbolInfo' <<<----- Obtain a description of a native (C/Fortran) symbol

	## alias	 help(getNativeSymbolInfo)

##___ Examples ___:

getNativeSymbolInfo("dansari")

library(mva)
getNativeSymbolInfo(symbol.For("hcass2"))
detach("package:mva")

## Keywords: 'interface'.


