###--- >>> `outer' <<<----- Outer Product of Arrays

	## alias	 help(outer)
	## alias	 help(\%o\%)

##___ Examples ___:

x <- 1:9; names(x) <- x
# Multiplication & Power Tables
x %o% x
y <- 2:8; names(y) <- paste(y,":",sep="")
outer(y, x, "^")

outer(month.abb, 1999:2003, FUN = "paste")

## three way multiplication table:
x %o% x %o% y[1:3]

## Keywords: 'array'.


