###--- >>> `list.files' <<<----- List the Files in a Directory/Folder

	## alias	 help(list.files)
	## alias	 help(dir)

##___ Examples ___:

list.files(R.home())
## Only files starting with a-l or r (*including* uppercase):
dir("../..", pattern = "^[a-lr]",full.names=TRUE)

## Keywords: 'file'.


