###--- >>> `formula.nls' <<<----- Extract Model Formula from nls Object

	## alias	 help(formula.nls)

##___ Examples ___:

data(Orange)
fm1 <- nls(circumference ~ A/(1+exp((B-age)/C)), Orange,
  start = list(A=160, B=700, C = 350))
formula(fm1)

## Keywords: 'models'.


