###--- >>> `missing' <<<----- Does a Formal Argument have a Value?

	## alias	 help(missing)

##___ Examples ___:

myplot <- function(x,y) {
                if(missing(y)) {
                        y <- x
                        x <- 1:length(y)
                }
                plot(x,y)
        }

## Keywords: 'programming'.


