###--- >>> `model.frame' <<<----- Extracting the ``Environment'' of a Model Formula

	## alias	 help(model.frame)
	## alias	 help(model.frame.default)
	## alias	 help(model.frame.lm)
	## alias	 help(model.frame.glm)
	## alias	 help(model.frame.aovlist)

##___ Examples ___:

data(cars)
data.class(model.frame(dist ~ speed, data = cars))

## Keywords: 'models'.


