###--- >>> `plot.table' <<<----- Plot Methods for `table' Objects

	## alias	 help(plot.table)

##___ Examples ___:

## 1-d tables
(Poiss.tab <- table(N = rpois(200, lam= 5)))
plot(Poiss.tab, main = "plot(table(rpois(200, lam=5)))")

data(state)
plot(table(state.division))

## 4-D :
data(Titanic)
plot(Titanic, main ="plot(Titanic, main= *)")


## Keywords: 'hplot', 'category'.


