###--- >>> `strsplit' <<<----- Split the Elements of a Character Vector

	## alias	 help(strsplit)

##___ Examples ___:

noquote(strsplit("A text I want to display with spaces", NULL)[[1]])

x <- c("asfef", "qwerty", "yuiop[", "b", "stuff.blah.yech")
# split x on the letter e
strsplit(x,"e")

unlist(strsplit("a.b.c", "."))
## [1] "" "" "" "" ""
## Note that `split' is a regexp!
## If you really want to split on `.', use
unlist(strsplit("a.b.c", "\\."))
## [1] "a" "b" "c"

## Keywords: 'character'.


