###--- >>> `stackloss' <<<----- Brownlee's Stack Loss Plant Data

	## alias	 help(stackloss)
	## alias	 help(stack.loss)
	## alias	 help(stack.x)

##___ Examples ___:

data(stackloss)
summary(lm.stack <- lm(stack.loss ~ stack.x))

## Keywords: 'datasets'.


