###--- >>> `attributes' <<<----- Object Attribute Lists

	## alias	 help(attributes)
	## alias	 help(attributes<-)
	## alias	 help(mostattributes<-)

##___ Examples ___:

x <- cbind(a=1:3, pi=pi) # simple matrix w/ dimnames
str(attributes(x))

## strip an object's attributes:
attributes(x) <- NULL
x # now just a vector of length 6

mostattributes(x) <- list(mycomment = "really special", dim = 3:2,
   dimnames = list(LETTERS[1:3], letters[1:5]), names = paste(1:6))
x # dim(), but not {dim}names

## Keywords: 'attribute'.


