###--- >>> `make.link' <<<----- Create a Link for GLM families

	## alias	 help(make.link)

##___ Examples ___:

str(make.link("logit"))

l2 <- make.link(2)
l2$linkfun(0:3)# 0 1 4 9
l2$mu.eta(eta= 1:2)#= 1/(2*sqrt(eta))

## Keywords: 'models'.


