###--- >>> `effects' <<<----- Effects from Fitted Model

	## alias	 help(effects)
	## alias	 help(effects.lm)
	## alias	 help(effects.glm)

##___ Examples ___:

y <- c(1:3,7,5)
x <- c(1:3,6:7)
( ee <- effects(lm(y ~ x)) )
c(round(ee - effects(lm(y+10 ~ I(x-3.8))),3))# just the first is different

## Keywords: 'models', 'regression'.


