###--- >>> `presidents' <<<----- Approval Rating of US Presidents

	## alias	 help(presidents)

##___ Examples ___:

data(presidents)
plot(presidents, las = 1, ylab = "Approval rating (%)",
     main = "presidents data")

## Keywords: 'datasets'.


