###--- >>> `asVector' <<<----- Coerce an Object to a Vector

	## alias	 help(asVector)
	## alias	 help(asVector.xyVector)

##___ Examples ___:

data( women )
ispl <- interpSpline( weight ~ height,  women )
pred <- predict(ispl)
class(pred)
str(pred)
asVector(pred)

## Keywords: 'models'.


