###--- >>> `ToothGrowth' <<<----- The Effect of Vitamin C on Tooth Growth in Guinea Pigs

	## alias	 help(ToothGrowth)

##___ Examples ___:

data(ToothGrowth)
coplot(len ~ dose | supp, data = ToothGrowth, panel = panel.smooth,
       xlab = "ToothGrowth data: given is supplement type")

## Keywords: 'datasets'.


