###--- >>> `print.default' <<<----- Default Printing

	## alias	 help(print.default)
	## alias	 help(print.atomic)

##___ Examples ___:

pi
print(pi, digits = 16)
LETTERS[1:16]
print(LETTERS, quote = FALSE)

## Keywords: 'print'.


