###--- >>> `is.R' <<<----- Are we using R, rather than S?

	## alias	 help(is.R)

##___ Examples ___:

x <- runif(20); small <- x < 0.4
# `which()' only exists in R:
if(is.R()) which(small) else seq(along=small)[small]

## Keywords: 'environment', 'utilities'.


