###--- >>> `write' <<<----- Write Data to a File

	## alias	 help(write)

##___ Examples ___:

# create a 2 by 5 matrix
x <- matrix(1:10,ncol=5)

# the file data contains x, two rows, five cols
# 1 3 5 6 9 will form the first row
write(t(x))

# the file data now contains the data in x,
# two rows, five cols but the first row is 1 2 3 4 5
write(x)
unlink("data") # tidy up

## Keywords: 'file', 'connection'.


