###--- >>> `power.prop.test' <<<----- Power calculations two sample test for of proportions

	## alias	 help(power.prop.test)

##___ Examples ___:

 power.prop.test(n=50, p1=.50, p2=.75)
 power.prop.test(p1=.50, p2=.75, power=.90)
 power.prop.test(n=50, p1=.5, power=.90)

## Keywords: 'htest'.


