###--- >>> `na.fail' <<<----- Handle Missing Values in Objects

	## alias	 help(na.fail)
	## alias	 help(na.fail.default)
	## alias	 help(na.omit)
	## alias	 help(na.omit.data.frame)
	## alias	 help(na.omit.default)
	## alias	 help(na.exclude)
	## alias	 help(na.exclude.data.frame)
	## alias	 help(na.exclude.default)

##___ Examples ___:

DF <- data.frame(x = c(1, 2, 3), y = c(0, 10, NA))
na.omit(DF)
m <- as.matrix(DF)
na.omit(m)
stopifnot(all(na.omit(1:3) == 1:3))  # does not affect objects with no NA's
try(na.fail(DF))#> Error: missing values in ...

options("na.action")

## Keywords: 'NA'.


