###--- >>> `char.expand' <<<----- Expand a String with Respect to a Target Table

	## alias	 help(char.expand)

##___ Examples ___:

locPars <- c("mean", "median", "mode")
char.expand("me", locPars, warning("Could not expand!"))
char.expand("mo", locPars)

## Keywords: 'character'.


