###--- >>> `update.formula' <<<----- Model Updating

	## alias	 help(update.formula)

##___ Examples ___:

update.formula(y ~ x,    ~ . + x2) #> y ~ x + x2
update.formula(y ~ x, log(.) ~ . ) #> log(y) ~ x

## Keywords: 'models'.


