###--- >>> `package.skeleton' <<<----- Create a skeleton for a new package

	## alias	 help(package.skeleton)

##___ Examples ___:

##Don't run: 
##D     f<-function(x,y) x+y
##D     g<-function(x,y) x-y
##D     d<-data.frame(a=1,b=2)
##D     e<-rnorm(1000)
##D     package.skeleton(list=c("f","g","d","e"),name="AnExample")


## Keywords: 'file', 'utilities'.


