###--- >>> `call' <<<----- Function Calls

	## alias	 help(call)
	## alias	 help(is.call)
	## alias	 help(as.call)

##___ Examples ___:

is.call(call) #-> FALSE: Functions are NOT calls

# set up a function call to round with argument 10.5
cl <- call("round", 10.5)
is.call(cl)# TRUE
cl
# such a call can also be evaluated.
eval(cl)# [1] 10

## Keywords: 'programming', 'attribute'.


