###--- >>> `power.t.test' <<<----- Power calculations for one and two sample t tests

	## alias	 help(power.t.test)

##___ Examples ___:

 power.t.test(n=20, delta=1)
 power.t.test(power=.90, delta=1)
 power.t.test(power=.90, delta=1, alt="one.sided")

## Keywords: 'htest'.


