###--- >>> `ls' <<<----- List Objects

	## alias	 help(ls)
	## alias	 help(objects)

##___ Examples ___:

.Ob <- 1
ls(pat="O")
ls(pat="O", all = TRUE)    # also shows ".[foo]"

# shows an empty list because inside myfunc no variables are defined
myfunc <- function() {ls()}
myfunc()

# define a local variable inside myfunc
myfunc <- function() {y <- 1; ls()}
myfunc()                # shows "y"

## Keywords: 'environment'.


