###--- >>> `SignRank' <<<----- Distribution of the Wilcoxon Signed Rank Statistic

	## alias	 help(dsignrank)
	## alias	 help(psignrank)
	## alias	 help(qsignrank)
	## alias	 help(rsignrank)

##___ Examples ___:

par(mfrow=c(2,2))
for(n in c(4:5,10,40)) {
  x <- seq(0, n*(n+1)/2, length=501)
  plot(x, dsignrank(x,n=n), type='l', main=paste("dsignrank(x,n=",n,")"))
}

## Keywords: 'distribution'.


