###--- >>> `library.dynam' <<<----- Loading Shared Libraries

	## alias	 help(library.dynam)
	## alias	 help(.Dyn.libs)

##___ Examples ___:

library.dynam()# which packages have been ``dynamically loaded''

## Keywords: 'data'.


