###--- >>> `predict' <<<----- Model Predictions

	## alias	 help(predict)

##___ Examples ___:

## All the "predict" methods available in your current search() path:
for(fn in methods("predict"))
   cat(fn,":\n\t",deparse(args(get(fn))),"\n")

## Keywords: 'methods'.


