###--- >>> `cat' <<<----- Concatenate and Print

	## alias	 help(cat)

##___ Examples ___:

iter <- rpois(1, lambda=10)
## print an informative message
cat("iteration = ", iter <- iter + 1, "\n")

## `fill' and label lines:
cat(paste(letters, 100* 1:26), fill = TRUE,
    labels = paste("{",1:10,"}:",sep=""))

## Keywords: 'print', 'file', 'connection'.


