###--- >>> `subset' <<<----- Subsetting Vectors and Data Frames

	## alias	 help(subset)
	## alias	 help(subset.default)
	## alias	 help(subset.data.frame)

##___ Examples ___:

data(airquality)
subset(airquality, Temp > 80, select = c(Ozone, Temp))
subset(airquality, Day == 1, select = -Temp)
subset(airquality, select = Ozone:Wind)

attach(airquality)
subset(Ozone, Temp > 80)

## Keywords: 'manip'.


