###--- >>> `Comparison' <<<----- Relational Operators

	## alias	 help(<)
	## alias	 help(<=)
	## alias	 help(==)
	## alias	 help(!=)
	## alias	 help(>=)
	## alias	 help(>)
	## alias	 help(Comparison)

##___ Examples ___:

x <- rnorm(20)
x < 1
x[x > 0]

x1 <- 0.5 - 0.3
x2 <- 0.3 - 0.1
x1 == x2                           # FALSE on most machines
identical(all.equal(x1, x2), TRUE) # TRUE everywhere

## Keywords: 'logic'.


