###--- >>> `Sys.info' <<<----- Extract System and User Information

	## alias	 help(Sys.info)

##___ Examples ___:

Sys.info()
## An alternative (and probably better) way to get the login name on Unix
Sys.getenv("LOGNAME")

## Keywords: 'utilities'.


