###--- >>> `shapiro.test' <<<----- Shapiro-Wilk Normality Test

	## alias	 help(shapiro.test)

##___ Examples ___:

shapiro.test(rnorm(100, mean = 5, sd = 3))
shapiro.test(runif(100, min = 2, max = 4))

## Keywords: 'htest'.


