###--- >>> `is.empty.model' <<<----- Check if a Model is Empty

	## alias	 help(is.empty.model)

##___ Examples ___:

y <- rnorm(20)
is.empty.model(y ~ 0)
is.empty.model(y ~ -1)
is.empty.model(lm(y ~ 0))

## Keywords: 'models'.


