###--- >>> `supsmu' <<<----- Friedman's SuperSmoother

	## alias	 help(supsmu)

##___ Examples ___:

data(cars)
attach(cars)
plot(speed, dist)
lines(supsmu(speed, dist))
lines(supsmu(speed, dist, bass=7), lty=2)
detach()

## Keywords: 'smooth'.


