###--- >>> `women' <<<----- Average Heights and Weights for American Women

	## alias	 help(women)

##___ Examples ___:

data(women)
plot(women, xlab = "Height (in)", ylab = "Weight (lb)",
     main = "women data: American women aged 30-39")

## Keywords: 'datasets'.


