###--- >>> `dimnames' <<<----- Dimnames of an Object

	## alias	 help(dimnames)
	## alias	 help(dimnames<-)
	## alias	 help(dimnames.data.frame)
	## alias	 help(dimnames<-.data.frame)

##___ Examples ___:

## simple versions of rownames and colnames
## could be defined as follows
rownames0 <- function(x) dimnames(x)[[1]]
colnames0 <- function(x) dimnames(x)[[2]]

## Keywords: 'array', 'manip'.


