###--- >>> `plot.xy' <<<----- Basic Internal Plot Function

	## alias	 help(plot.xy)

##___ Examples ___:

points.default # to see how it calls "plot.xy(xy.coords(x, y), ...)"

## Keywords: 'aplot'.


