###--- >>> `logLik.glm' <<<----- Extract Log-Likelihood from an glm Object

	## alias	 help(logLik.glm)

##___ Examples ___:

example("glm", echo = FALSE)
##-- Continuing the  glm(.) example:
Eq <- function(x,y) all.equal(x,y, tol = 1e-12)
stopifnot(Eq(AIC(anorex.1), anorex.1$aic),
          Eq(AIC(g1), g1$aic),
          Eq(AIC(g2), g2$aic))

## Keywords: 'models'.


