###--- >>> `DateTimeClasses' <<<----- Date-Time Classes

	## alias	 help(DateTimeClasses)
	## alias	 help(POSIXct)
	## alias	 help(POSIXlt)
	## alias	 help(print.POSIXct)
	## alias	 help(print.POSIXlt)
	## alias	 help(summary.POSIXct)
	## alias	 help(summary.POSIXlt)
	## alias	 help(+.POSIXt)
	## alias	 help(-.POSIXt)
	## alias	 help(Ops.POSIXt)
	## alias	 help(Math.POSIXt)
	## alias	 help(Summary.POSIXct)
	## alias	 help(Math.POSIXlt)
	## alias	 help(Summary.POSIXlt)
	## alias	 help([.POSIXct)
	## alias	 help([<-.POSIXct)
	## alias	 help([[.POSIXct)
	## alias	 help(as.data.frame.POSIXct)
	## alias	 help(.leap.seconds)
	## alias	 help(is.na.POSIXlt)
	## alias	 help(all.equal.POSIXct)
	## alias	 help(c.POSIXct)
	## alias	 help(c.POSIXlt)
	## alias	 help(as.matrix.POSIXlt)
	## alias	 help(mean.POSIXct)
	## alias	 help(mean.POSIXlt)
	## alias	 help(str.POSIXt)
	## alias	 help(-.POSIXct)
	## alias	 help(-.POSIXlt)
	## alias	 help(Ops.POSIXct)
	## alias	 help(Ops.POSIXlt)

##___ Examples ___:

(z <- Sys.time())             # the current date, as class "POSIXct"

Sys.time() - 3600             # an hour ago

as.POSIXlt(Sys.time(), "GMT") # the current time in GMT
format(.leap.seconds)         # all 22 leapseconds in your timezone


str(.leap.seconds)

## Wouldn't we want a  diff.POSIXt()  method ?
(dls <- .leap.seconds[-1] - .leap.seconds[-22])
table(dls)


## Keywords: 'utilities', 'chron'.


