###--- >>> `toString' <<<----- toString Converts its Argument to a Character String

	## alias	 help(toString)
	## alias	 help(toString.default)

##___ Examples ___:

x <- c("a", "b", "aaaaaaaaaaa")
toString(x)
toString(x, width=8)

## Keywords: 'utilities'.


