###--- >>> `dataentry' <<<----- Spreadsheet Interface for Entering Data

	## alias	 help(data.entry)
	## alias	 help(dataentry)
	## alias	 help(de)
	## alias	 help(de.ncols)
	## alias	 help(de.restore)
	## alias	 help(de.setup)

##___ Examples ___:

# call data entry with variables x and y
##Don't run: data.entry(x,y)

## Keywords: 'utilities', 'file'.


