###--- >>> `range' <<<----- Range of Values

	## alias	 help(range)
	## alias	 help(range.default)

##___ Examples ___:

print(r.x <- range(rnorm(100)))
diff(r.x) # the SAMPLE range

x <- c(NA, 1:3, -1:1/0); x
range(x)
range(x, na.rm = TRUE)
range(x, finite = TRUE)

## Keywords: 'univar', 'arith'.


