###--- >>> `quit' <<<----- Terminate an R Session

	## alias	 help(quit)
	## alias	 help(q)
	## alias	 help(.Last)

##___ Examples ___:

##Don't run: ## Unix-flavour example
##D .Last <- function() {
##D   cat("Now sending PostScript graphics to the printer:\n")
##D   system("lpr Rplots.ps")
##D   cat("bye bye...\n")
##D }
##D quit("yes")

## Keywords: 'environment'.


