###--- >>> `rle' <<<----- Run Length Encoding

	## alias	 help(rle)
	## alias	 help(inverse.rle)
	## alias	 help(print.rle)

##___ Examples ___:

x <- rev(rep(6:10, 1:5))
rle(x)
## lengths [1:5]  5 4 3 2 1
## values  [1:5] 10 9 8 7 6

z <- c(TRUE,TRUE,FALSE,FALSE,TRUE,FALSE,TRUE,TRUE,TRUE)
rle(z)
rle(as.character(z))

stopifnot(x == inverse.rle(rle(x)),
          z == inverse.rle(rle(z)))

## Keywords: 'manip'.


