###--- >>> `attr' <<<----- Object Attributes

	## alias	 help(attr)
	## alias	 help(attr<-)

##___ Examples ___:

# create a 2 by 5 matrix
x <- 1:10
attr(x,"dim") <- c(2, 5)

## Keywords: 'attribute'.


