###--- >>> `system.file' <<<----- Find Names of R System Files

	## alias	 help(system.file)

##___ Examples ___:

system.file()                # The root of the `base' package
system.file(package = "lqs") # The root of package `lqs'
system.file("INDEX")
system.file("help", "AnIndex", package = "stepfun")

## Keywords: 'file', 'utilities'.


