###--- >>> `dendrogram' <<<----- General Tree Structures

	## alias	 help(as.dendrogram)
	## alias	 help(as.dendrogram.hclust)
	## alias	 help(plot.dendrogram)
	## alias	 help(plotNode)
	## alias	 help(plotNodeLimit)
	## alias	 help(cut.dendrogram)

##___ Examples ___:

library(mva)
data(USArrests)
hc <- hclust(dist(USArrests), "ave")
str(dend1 <- as.dendrogram(hc))
plot(dend1)
dend2 <- cut(dend1, h=70)
plot(dend2$upper)
plot(dend2$lower[[3]])

## Keywords: 'multivariate'.


