###--- >>> `deparse' <<<----- Expression Deparsing

	## alias	 help(deparse)

##___ Examples ___:

deparse(args(lm))
deparse(args(lm), width = 100)
myplot <-
function(x, y)
    plot(x, y, xlab=deparse(substitute(x)),
        ylab=deparse(substitute(y)))

## Keywords: 'programming', 'manip', 'data'.


