###--- >>> `matrix' <<<----- Matrices

	## alias	 help(matrix)
	## alias	 help(as.matrix)
	## alias	 help(as.matrix.default)
	## alias	 help(as.matrix.data.frame)
	## alias	 help(is.matrix)

##___ Examples ___:

is.matrix(as.matrix(1:10))
data(warpbreaks)
!is.matrix(warpbreaks)# data.frame, NOT matrix!
str(warpbreaks)
str(as.matrix(warpbreaks))#using as.matrix.data.frame(.) method

## Keywords: 'array', 'algebra'.


