###--- >>> `difftime' <<<----- Time Intervals

	## alias	 help(difftime)
	## alias	 help(print.difftime)
	## alias	 help(round.difftime)

##___ Examples ___:

(z <- Sys.time() - 3600)
Sys.time() - z                # just over 3600 seconds.

## time interval between releases of 1.2.2 and 1.2.3.
ISOdate(2001, 4, 26) - ISOdate(2001, 2, 26)

## Keywords: 'utilities', 'chron'.


