###--- >>> `dim' <<<----- Dimensions of an Object

	## alias	 help(dim)
	## alias	 help(dim.data.frame)
	## alias	 help(dim<-)

##___ Examples ___:

x <- 1:12 ; dim(x) <- c(3,4)
x

# simple versions of nrow and ncol could be defined as follows
nrow0 <- function(x) dim(x)[1]
ncol0 <- function(x) dim(x)[2]

## Keywords: 'array'.


