###--- >>> `package.contents' <<<----- Package Contents and Description

	## alias	 help(package.contents)
	## alias	 help(package.description)

##___ Examples ___:

package.contents("mva")
package.contents("mva")[, c("Entry", "Description")]

package.description("ts")
package.description("ts")[c("Package", "Version")]
## NOTE: No subscripting using `$' or abbreviated field tags!

## Keywords: 'utilities'.


