###--- >>> `Arithmetic' <<<----- Arithmetic Operators

	## alias	 help(+)
	## alias	 help(-)
	## alias	 help(*)
	## alias	 help(/)
	## alias	 help(^)
	## alias	 help(\%\%)
	## alias	 help(\%/\%)
	## alias	 help(Arithmetic)

##___ Examples ___:

x <- -1:12
x + 1
2 * x + 3
x %% 2 #-- is periodic
x %/% 5

## Keywords: 'arith'.


