###--- >>> `xy.coords' <<<----- Extracting Plotting Structures

	## alias	 help(xy.coords)

##___ Examples ___:

xy.coords(fft(c(1:10)), NULL)
data(cars) ; attach(cars)
xy.coords(dist ~ speed, NULL)$xlab # = "speed"

str(xy.coords(1:3, 1:2, recycle=TRUE))
str(xy.coords(-2:10,NULL, log="y")) 
##> warning: 3 y values <=0 omitted ..

## Keywords: 'dplot'.


