###--- >>> `library' <<<----- Loading and Listing of Packages

	## alias	 help(library)
	## alias	 help(require)
	## alias	 help(R_LIBS)
	## alias	 help(.Autoloaded)
	## alias	 help(.First.lib)
	## alias	 help(.Last.lib)
	## alias	 help(.Library)
	## alias	 help(.find.package)
	## alias	 help(.packages)
	## alias	 help(.path.package)
	## alias	 help(.lib.loc)
	## alias	 help(.libPaths)
	## alias	 help(print.libraryIQR)

##___ Examples ___:

(.packages())               # maybe just "base"
.packages(all = TRUE)       # return all available as character vector
library()                   # list all available packages
library(lib = .Library)     # list all packages in the default library
library(help = eda)         # documentation on package `eda'
library(eda)                # load package `eda'
require(eda)                # the same
(.packages())               # "eda", too
detach("package:eda")

# if the package name is in a character vector, use
pkg <- "eda"
library(pkg, character.only = TRUE)
detach(pos = match(paste("package", pkg, sep=":"), search()))

.path.package()
.Autoloaded                 # maybe "ctest"

.libPaths()                 # all library trees R knows about

require(nonexistent)        # FALSE
##Don't run: ## Suppose a package needs to call a shared library named `fooEXT',
##D ## where `EXT' is the system-specific extension.  Then you should use
##D .First.lib <- function(lib, pkg) {
##D   library.dynam("foo", pkg, lib)
##D }

## Keywords: 'data'.


