###--- >>> `cut.POSIXt' <<<----- Convert a Date-Time Object to a Factor

	## alias	 help(cut.POSIXt)

##___ Examples ___:

## random dates in a 10-week period
cut(ISOdate(2001, 1, 1) + 70*86400*runif(100), "weeks")

## Keywords: 'manip', 'chron'.


