###--- >>> `make.socket' <<<----- Create a Socket Connection

	## alias	 help(make.socket)
	## alias	 help(print.socket)

##___ Examples ___:

daytime <- function(host = "localhost"){
    a <- make.socket(host, 13)
    on.exit(close.socket(a))
    read.socket(a)
}
## Offical time (UTC) from US Naval Observatory
##Don't run: daytime("tick.usno.navy.mil")

## Keywords: 'misc'.


