###--- >>> `numericDeriv' <<<----- Evaluate derivatives numerically

	## alias	 help(numericDeriv)

##___ Examples ___:

myenv <- new.env()
assign("mean", 0., env = myenv)
assign("sd", 1., env = myenv)
assign("x", seq(-3., 3., len = 31), env = myenv)
numericDeriv(quote(pnorm(x, mean, sd)), c("mean", "sd"), myenv)

## Keywords: 'models'.


