###--- >>> `phones' <<<----- The World's Telephones

	## alias	 help(phones)

##___ Examples ___:

data(phones)
matplot(rownames(phones), phones, type = "b", log = "y",
        xlab = "Year", ylab = "Number of telephones (1000's)")
legend(1951.5, 80000, colnames(phones), col = 1:7, lty = 1:7, pch = rep(21, 7))
title(main = "phones data: log scale for response")

## Keywords: 'datasets'.


