###--- >>> `TkWidgetcmds' <<<----- Tk widget commands

	## alias	 help(TkWidgetcmds)
	## alias	 help(tkactivate)
	## alias	 help(tkadd)
	## alias	 help(tkaddtag)
	## alias	 help(tkbbox)
	## alias	 help(tkcanvasx)
	## alias	 help(tkcanvasy)
	## alias	 help(tkcget)
	## alias	 help(tkcompare)
	## alias	 help(tkconfigure)
	## alias	 help(tkcoords)
	## alias	 help(tkcreate)
	## alias	 help(tkcurselection)
	## alias	 help(tkdchars)
	## alias	 help(tkdebug)
	## alias	 help(tkdelete)
	## alias	 help(tkdelta)
	## alias	 help(tkdeselect)
	## alias	 help(tkdlineinfo)
	## alias	 help(tkdtag)
	## alias	 help(tkdump)
	## alias	 help(tkentrycget)
	## alias	 help(tkentryconfigure)
	## alias	 help(tkfind)
	## alias	 help(tkflash)
	## alias	 help(tkfraction)
	## alias	 help(tkget)
	## alias	 help(tkgettags)
	## alias	 help(tkicursor)
	## alias	 help(tkidentify)
	## alias	 help(tkimage.cget)
	## alias	 help(tkimage.configure)
	## alias	 help(tkimage.create)
	## alias	 help(tkimage.names)
	## alias	 help(tkindex)
	## alias	 help(tkinsert)
	## alias	 help(tkinvoke)
	## alias	 help(tkitembind)
	## alias	 help(tkitemcget)
	## alias	 help(tkitemconfigure)
	## alias	 help(tkitemfocus)
	## alias	 help(tkitemlower)
	## alias	 help(tkitemraise)
	## alias	 help(tkitemscale)
	## alias	 help(tkmark.gravity)
	## alias	 help(tkmark.names)
	## alias	 help(tkmark.next)
	## alias	 help(tkmark.previous)
	## alias	 help(tkmark.set)
	## alias	 help(tkmark.unset)
	## alias	 help(tkmove)
	## alias	 help(tknearest)
	## alias	 help(tkpost)
	## alias	 help(tkpostcascade)
	## alias	 help(tkpostscript)
	## alias	 help(tkscan.mark)
	## alias	 help(tkscan.dragto)
	## alias	 help(tksearch)
	## alias	 help(tksee)
	## alias	 help(tkselect)
	## alias	 help(tkselection.adjust)
	## alias	 help(tkselection.anchor)
	## alias	 help(tkselection.clear)
	## alias	 help(tkselection.from)
	## alias	 help(tkselection.includes)
	## alias	 help(tkselection.present)
	## alias	 help(tkselection.range)
	## alias	 help(tkselection.set)
	## alias	 help(tkselection.to)
	## alias	 help(tkset)
	## alias	 help(tksize)
	## alias	 help(tktoggle)
	## alias	 help(tktag.add)
	## alias	 help(tktag.bind)
	## alias	 help(tktag.cget)
	## alias	 help(tktag.configure)
	## alias	 help(tktag.delete)
	## alias	 help(tktag.lower)
	## alias	 help(tktag.names)
	## alias	 help(tktag.nextrange)
	## alias	 help(tktag.prevrange)
	## alias	 help(tktag.raise)
	## alias	 help(tktag.ranges)
	## alias	 help(tktag.remove)
	## alias	 help(tktype)
	## alias	 help(tkunpost)
	## alias	 help(tkwindow.cget)
	## alias	 help(tkwindow.configure)
	## alias	 help(tkwindow.create)
	## alias	 help(tkwindow.names)
	## alias	 help(tkxview)
	## alias	 help(tkxview.moveto)
	## alias	 help(tkxview.scroll)
	## alias	 help(tkyposition)
	## alias	 help(tkyview)
	## alias	 help(tkyview.moveto)
	## alias	 help(tkyview.scroll)

##___ Examples ___:

##Don't run: 
##D ## These cannot be run by examples() but should be OK when pasted
##D ## into an interactive R session with the tcltk package loaded
##D 
##D tt <- tktoplevel()
##D tkpack(txt.w <- tktext(tt))
##D tkinsert(txt.w, "0.0", "plot(1:10)")
##D 
##D # callback function 
##D eval.txt <- function()
##D    eval(parse(text=tkget(txt.w, "0.0", "end")))
##D tkpack(but.w <- tkbutton(tt,text="Submit", command=eval.txt))
##D 
##D ## Try pressing the button, edit the text and when finished:
##D 
##D tkdestroy(tt)



## Keywords: 'misc'.


