###--- >>> `function' <<<----- Function Definition

	## alias	 help(function)
	## alias	 help(return)

##___ Examples ___:

norm <- function(x) sqrt(x%*%x)
norm(1:4)

## An anonymous function:
(function(x,y){ z <- x^2 + y^2; x+y+z })(0:7, 1)

## Keywords: 'programming'.


