###--- >>> `discoveries' <<<----- Numbers of Important Discoveries

	## alias	 help(discoveries)

##___ Examples ___:

data(discoveries)
plot(discoveries, ylab = "Number of important discoveries",
     las = 1)
title(main = "discoveries data set")

## Keywords: 'datasets'.


