###--- >>> `case/variable.names' <<<----- Case and Variable Names of Fitted Models

	## alias	 help(case.names)
	## alias	 help(case.names.lm)
	## alias	 help(case.names.default)
	## alias	 help(variable.names)
	## alias	 help(variable.names.lm)
	## alias	 help(variable.names.default)

##___ Examples ___:

x <- 1:20
y <-  x + (x/4 - 2)^3 + rnorm(20, s=3)
names(y) <- paste("O",x,sep=".")
ww <- rep(1,20); ww[13] <- 0
summary(lmxy <- lm(y ~ x + I(x^2)+I(x^3) + I((x-10)^2),
                   weights = ww), cor = TRUE)
variable.names(lmxy)
variable.names(lmxy, full= TRUE)# includes the last
case.names(lmxy)
case.names(lmxy, full = TRUE)# includes the 0-weight case

## Keywords: 'regression', 'models'.


