###--- >>> `Extremes' <<<----- Maxima and Minima

	## alias	 help(max)
	## alias	 help(min)
	## alias	 help(pmax)
	## alias	 help(pmin)

##___ Examples ___:

min(5:1,pi)
pmin(5:1, pi)
x <- sort(rnorm(100));  cH <- 1.35
pmin(cH, quantile(x)) # no names
pmin(quantile(x), cH) # has names
plot(x, pmin(cH, pmax(-cH, x)), type='b', main= "Huber's function")

## Keywords: 'univar', 'arith'.


