###--- >>> `transform' <<<----- Transform an Object, e.g. a Data Frame

	## alias	 help(transform)
	## alias	 help(transform.default)
	## alias	 help(transform.data.frame)

##___ Examples ___:

data(airquality)
transform(airquality, Ozone = -Ozone)
transform(airquality, new = -Ozone, Temp = (Temp-32)/1.8)

attach(airquality)
transform(Ozone, logOzone = log(Ozone)) # marginally interesting ...
detach(airquality)

## Keywords: 'manip'.


