###--- >>> `cmdscale' <<<----- Classical (Metric) Multidimensional Scaling

	## alias	 help(cmdscale)

##___ Examples ___:

data(eurodist)
loc <- cmdscale(eurodist)
x <- loc[,1]
y <- -loc[,2]
plot(x, y, type="n", xlab="", ylab="", main="cmdscale(eurodist)")
text(x, y, names(eurodist), cex=0.8)


## failed in versions <= 1.4.0 :
cmdscale(eurodist, k = 1)


## Keywords: 'multivariate'.


