###--- >>> `pos.to.env' <<<----- Convert Positions in the Search Path to Environments

	## alias	 help(pos.to.env)

##___ Examples ___:

pos.to.env(1) # R_GlobalEnv
# the next returns NULL, which is how package:base is represented.
pos.to.env(length(search()))

## Keywords: 'utilities'.


