###--- >>> `dev.xxx' <<<----- Control Multiple Devices

	## alias	 help(dev.cur)
	## alias	 help(dev.list)
	## alias	 help(dev.next)
	## alias	 help(dev.prev)
	## alias	 help(dev.off)
	## alias	 help(dev.set)
	## alias	 help(.Device)
	## alias	 help(.Devices)
	## alias	 help(graphics.off)

##___ Examples ___:

##Don't run: ## Unix-specific example
##D x11()
##D plot(1:10)
##D x11()
##D plot(rnorm(10))
##D dev.set(dev.prev())
##D abline(0,1)# through the 1:10 points
##D dev.set(dev.next())
##D abline(h=0, col="gray")# for the residual plot
##D dev.set(dev.prev())
##D dev.off(); dev.off()#- close the two X devices


## Keywords: 'device', 'iplot'.


