###--- >>> `units' <<<----- Graphical Units

	## alias	 help(xinch)
	## alias	 help(yinch)
	## alias	 help(xyinch)
	## alias	 help(cm)

##___ Examples ___:

all(c(xinch(),yinch()) == xyinch()) # TRUE
xyinch()
xyinch #- to see that is really   delta{"usr"} / "pin"

cm(1)# = 2.54

## plot labels offset 0.12 inches to the right
## of plotted symbols in a plot
data(mtcars)
attach(mtcars)
plot(mpg, disp, pch=19, main= "Motor Trend Cars")
text(mpg + xinch(0.12), disp, rownames(mtcars),adj=0, cex = .7, col='blue')
detach(mtcars)

## Keywords: 'dplot'.


