###--- >>> `TkWidgets' <<<----- Tk widgets

	## alias	 help(TkWidgets)
	## alias	 help(tkwidget)
	## alias	 help(tkbutton)
	## alias	 help(tkcanvas)
	## alias	 help(tkcheckbutton)
	## alias	 help(tkentry)
	## alias	 help(tkframe)
	## alias	 help(tklabel)
	## alias	 help(tklistbox)
	## alias	 help(tkmenu)
	## alias	 help(tkmenubutton)
	## alias	 help(tkmessage)
	## alias	 help(tkradiobutton)
	## alias	 help(tkscale)
	## alias	 help(tkscrollbar)
	## alias	 help(tktext)
	## alias	 help(tktoplevel)

##___ Examples ___:

##Don't run: 
##D ## These cannot be run by examples() but should be OK when pasted
##D ## into an interactive R session with the tcltk package loaded
##D 
##D tt <- tktoplevel()
##D label.widget <- tklabel(tt, text="Hello, World!")
##D button.widget <- tkbutton(tt, text="Push",
##D                           command=function()cat("OW!\n"))
##D tkpack(label.widget, button.widget) # geometry manager
##D                                     # see Tk-commands
##D 
##D ## Push the button and then...
##D 
##D tkdestroy(tt)


## Keywords: 'misc'.


