###--- >>> `slot' <<<----- The Slots in an Object from a Formal Class

	## alias	 help(slot)
	## alias	 help(slot<-)
	## alias	 help(@<-)
	## alias	 help(slotNames)

##___ Examples ___:

##Don't run: 
##D   slot(myTrack, "x")
##D   slot(myTrack, "y") <- log(slot(myTrack, "x"))
##D 
##D   slotNames("track")

## Keywords: 'programming', 'classes'.


