###--- >>> `airmiles' <<<----- Commercial Airline Mileage

	## alias	 help(airmiles)

##___ Examples ___:

data(airmiles)
plot(airmiles, main = "airmiles data",
     xlab = "Passenger-miles flown by U.S. commercial airlines", col = 4)

## Keywords: 'datasets'.


