###--- >>> `UKLungDeaths' <<<----- Monthly Deaths from Lung Diseases in the UK

	## alias	 help(UKLungDeaths)
	## alias	 help(ldeaths)
	## alias	 help(fdeaths)
	## alias	 help(mdeaths)

##___ Examples ___:

data(UKLungDeaths)
plot(ldeaths) 
plot(mdeaths, fdeaths) 
## Better labels:
yr <- floor(tt <- time(mdeaths))
plot(mdeaths, fdeaths,
     xy.labels = paste(month.abb[12*(tt - yr)], yr-1900, sep="'"))

## Keywords: 'datasets'.


