###--- >>> `detach' <<<----- Detach Objects from the Search Path

	## alias	 help(detach)

##___ Examples ___:

require(eda)#package
detach(package:eda)
## could equally well use detach("package:eda")
## but NOT  pkg <- "package:eda"; detach(pkg)
## Instead, use
library(eda)
pkg <- "package:eda"
detach(pos = match(pkg, search()))

library(mva)
detach(2)# `pos' used for `name'

## Keywords: 'data'.


