###--- >>> `methods' <<<----- Class Methods

	## alias	 help(UseMethod)
	## alias	 help(NextMethod)
	## alias	 help(methods)

##___ Examples ___:

methods(summary)

methods(print)

methods(class = data.frame)

methods("[")  ##- does not list the C-internal ones...

## Keywords: 'methods'.


