###--- >>> `args' <<<----- Argument List of a Function

	## alias	 help(args)

##___ Examples ___:

args(c)            # -> NULL (c is a `primitive' function)
args(plot.default)

## Keywords: 'documentation'.


