###--- >>> `boxplot.formula' <<<----- Formula Notation for Box Plots

	## alias	 help(boxplot.formula)

##___ Examples ___:

data(OrchardSprays)
boxplot(decrease ~ treatment, data = OrchardSprays,
        log = "y", col="bisque")

## Keywords: 'hplot'.


