###--- >>> `reshapeLong-deprecated' <<<----- Reshape data frame to long format

	## alias	 help(reshapeLong-deprecated)

##___ Examples ___:

(dd<-as.data.frame(matrix(1:24,4)))
reshapeLong(dd,V3:V5)

## Keywords: 'manip'.


