###--- >>> `PlantGrowth' <<<----- Results from an Experiment on Plant Growth

	## alias	 help(PlantGrowth)

##___ Examples ___:

## One factor ANOVA example from Dobson's book, cf. Table 7.4:
data(PlantGrowth)
boxplot(weight ~ group, data = PlantGrowth, main = "PlantGrowth data",
        ylab = "Dried weight of plants", col = "lightgray",
        notch = TRUE, varwidth = TRUE)
anova(lm(weight ~ group, data = PlantGrowth))

## Keywords: 'datasets'.


