###--- >>> `p.adjust' <<<----- Adjust p values for multiple comparisons

	## alias	 help(p.adjust)
	## alias	 help(p.adjust.methods)

##___ Examples ___:

  p <- runif(50)
  p.adjust(p)

## Keywords: 'htest'.


