###--- >>> `asOneSidedFormula' <<<----- Convert to One-Sided Formula

	## alias	 help(asOneSidedFormula)

##___ Examples ___:

asOneSidedFormula("age")
asOneSidedFormula(~ age)

## Keywords: 'models'.


