###--- >>> `line' <<<----- Robust Line Fitting

	## alias	 help(line)
	## alias	 help(coef.tukeyline)
	## alias	 help(residuals.tukeyline)
	## alias	 help(fitted.tukeyline)
	## alias	 help(print.tukeyline)

##___ Examples ___:

library(eda)
data(cars)
plot(cars)
(z <- line(cars))
abline(coef(z))
## Tukey-Anscombe Plot :
plot(residuals(z) ~ fitted(z), main = deparse(z$call))

## Keywords: 'robust', 'regression'.


