###--- >>> `Lognormal' <<<----- The Log Normal Distribution

	## alias	 help(dlnorm)
	## alias	 help(plnorm)
	## alias	 help(qlnorm)
	## alias	 help(rlnorm)

##___ Examples ___:

dlnorm(1) == dnorm(0)
x <- rlnorm(1000)       # not yet always :
all(abs(x  -  qlnorm(plnorm(x))) < 1e4 * .Machine$double.eps * x)

## Keywords: 'distribution'.


