###--- >>> `stat.anova' <<<----- GLM Anova Statistics

	## alias	 help(stat.anova)

##___ Examples ___:

##-- Continued from  ``?glm'':
example("glm", echo = FALSE)
print(ag <- anova(glm.D93))
stat.anova(ag$table, test = "Cp",
           scale = sum(resid(glm.D93, "pearson")^2)/4, df = 4, n = 9)

## Keywords: 'regression', 'models'.


