###--- >>> `attach' <<<----- Attach Set of R Objects to Search Path

	## alias	 help(attach)

##___ Examples ___:

data(women)
summary(women$height) ## refers to variable `height' in the dataframe
attach(women)
summary(height)      ## The same variable now available by name
height<-height*2.54  ## Don't do this. It creates a new variable
detach("women")
summary(height)      ## The new variable created by modifying `height'
rm(height)

## Keywords: 'data'.


