###--- >>> `warnings' <<<----- Print Warning Messages

	## alias	 help(warnings)

##___ Examples ___:

ow <- options("warn")
for(w in -1:1) {
   options(warn = w); cat("\n warn =",w,"\n")
   for(i in 1:3) { cat(i,"..\n"); m <- matrix(1:7, 3,4) }
}
warnings()
options(ow) # reset

## Keywords: 'programming', 'error'.


