###--- >>> `length' <<<----- Length of a Vector or List

	## alias	 help(length)
	## alias	 help(length<-)

##___ Examples ___:

length(diag(4))# = 16 (4 x 4)
length(options())# 12 or more
length(y ~ x1 + x2 + x3)# 3
length(expression(x, {y <- x^2; y+2}, x^y)) # 3

## Keywords: 'attribute'.


