###--- >>> `varimax' <<<----- Rotation Methods for Factor Analysis

	## alias	 help(promax)
	## alias	 help(varimax)

##___ Examples ___:

data(swiss)
## varimax with normalize = T is the default
fa <- factanal( ~., 2, data = swiss)
varimax(fa$loadings, normalize = FALSE)
promax(fa$loadings)

## Keywords: 'multivariate'.


