###--- >>> `cumsum' <<<----- Cumulative Sums, Products, and Extremes

	## alias	 help(cumsum)
	## alias	 help(cumprod)
	## alias	 help(cummin)
	## alias	 help(cummax)

##___ Examples ___:

cumsum(1:10)
cumprod(1:10)
cummin(c(3:1, 2:0, 4:2))
cummax(c(3:1, 2:0, 4:2))

## Keywords: 'arith'.


