###--- >>> `add1' <<<----- Add or Drop All Possible Single Terms to a Model

	## alias	 help(add1)
	## alias	 help(add1.default)
	## alias	 help(add1.lm)
	## alias	 help(add1.glm)
	## alias	 help(add1.mlm)
	## alias	 help(drop1)
	## alias	 help(drop1.default)
	## alias	 help(drop1.lm)
	## alias	 help(drop1.glm)
	## alias	 help(drop1.mlm)

##___ Examples ___:

example(step)#-> swiss
add1(lm1, ~ I(Education^2) + .^2)
drop1(lm1, test="F")

example(glm)
drop1(glm.D93, test="Chisq")
drop1(glm.D93, test="F")

## Keywords: 'models'.


