###--- >>> `help.search' <<<----- Search the Help System

	## alias	 help(help.search)
	## alias	 help(print.hsearch)

##___ Examples ___:

help.search("linear models")    # In case you forgot how to fit linear
                                # models
##Don't run: 
##D help.search("print")            # All help pages with topics or title
##D                                 # matching `print'
##D help.search(apropos = "print")  # The same
##D 
##D help.search(keyword = "hplot")  # All help pages documenting high-level
##D                                 # plots.
##D 
##D ## Help pages with documented topics starting with `try'.
##D help.search("\\btry", fields = "alias")
##D ## Do not use `^' or `$' when matching aliases or keywords.


## Keywords: 'documentation'.


