###--- >>> `scatter.smooth' <<<----- Scatter Plot with Smooth Curve Fitted by Loess

	## alias	 help(scatter.smooth)
	## alias	 help(loess.smooth)

##___ Examples ___:

data(cars)
attach(cars)
scatter.smooth(speed, dist)
detach()

## Keywords: 'smooth'.


